@@ -1,21 +1,8 @@
-// File_Aac - Info for AAC files
-// Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -626,7 +613,7 @@ void File_Aac::StreamMuxConfig()
 {
     Element_Begin1("StreamMuxConfig");
 
-    bool useSameConfig,audioMuxVersion;
+    bool audioMuxVersion;
     Get_SB (audioMuxVersion,                                    "audioMuxVersion");
     if (audioMuxVersion)
         Get_SB (audioMuxVersionA,                               "audioMuxVersionA");
@@ -644,6 +631,7 @@ void File_Aac::StreamMuxConfig()
         }
 
         int8u streamCnt = 0;
+        bool useSameConfig;
 
         Get_SB (allStreamsSameTimeFraming,                      "allStreamsSameTimeFraming");
         Get_S1 (6, numSubFrames,                                "numSubFrames");
@@ -710,7 +698,7 @@ void File_Aac::StreamMuxConfig()
                 }
             }
         }
-        bool otherDataLenEsc, crcCheckPresent;
+        bool crcCheckPresent;
         Get_SB (otherDataPresent,                               "otherDataPresent");
         if (otherDataPresent)
         {
@@ -719,6 +707,7 @@ void File_Aac::StreamMuxConfig()
             else
             {
                 otherDataLenBits=0;
+                bool otherDataLenEsc;
                 do
                 {
                     int8u otherDataLenTmp;
@@ -838,7 +827,14 @@ void File_Aac::PayloadMux()
                 switch(frameLengthType[streamID[prog][lay]])
                 {
                     case 0 :
-                            raw_data_block(); //Skip_BS(8*MuxSlotLengthBytes[streamID[prog][lay]],"payload[streamID[prog][lay]]");
+                            if (CA_system_ID_MustSkipSlices)
+                            {
+                                //Encryption management
+                                Skip_BS(8*MuxSlotLengthBytes[streamID[prog][lay]], "Encrypted payload[streamID[prog][lay]]");
+                                Frame_Count_Valid=0;
+                            }
+                            else
+                                raw_data_block();
                             break;
                     case 1 :
                             Skip_BS(8 * (frameLength[streamID[prog][lay]] + 20),"payload[streamID[prog][lay]]");
@@ -1008,6 +1004,17 @@ void File_Aac::adts_frame()
     //Parsing
     adts_fixed_header();
     adts_variable_header();
+
+    //Encryption management
+    if (CA_system_ID_MustSkipSlices)
+    {
+        //Is not decodable
+        BS_End();
+        Skip_XX(Element_Size-Element_Offset,                    "Encrypted data");
+        Frame_Count_Valid=0;
+        return;
+    }
+
     if (num_raw_data_blocks==0)
     {
         if (!protection_absent)
