@@ -1,27 +1,15 @@
-// Enums - Automaticly generated enums for MediaInfo
-// Copyright (C) 2008-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Automaticly generated methods for MediaInfo
 // Don't modify, this will be deleted at the next automatic update
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 
 //---------------------------------------------------------------------------
 #ifndef MediaInfo_File__Analyze_AutomaticH
@@ -94,6 +82,7 @@ enum generic
     Generic_Delay_String3,
     Generic_Delay_String4,
     Generic_Delay_Settings,
+    Generic_Delay_DropFrame,
     Generic_Delay_Source,
     Generic_Delay_Source_String,
     Generic_Delay_Original,
@@ -103,6 +92,7 @@ enum generic
     Generic_Delay_Original_String3,
     Generic_Delay_Original_String4,
     Generic_Delay_Original_Settings,
+    Generic_Delay_Original_DropFrame,
     Generic_Delay_Original_Source,
     Generic_Video_Delay,
     Generic_Video_Delay_String,
@@ -158,6 +148,7 @@ enum general
     General_StreamKindID,
     General_StreamKindPos,
     General_StreamOrder,
+    General_FirstPacketOrder,
     General_Inform,
     General_ID,
     General_ID_String,
@@ -169,7 +160,7 @@ enum general
     General_VideoCount,
     General_AudioCount,
     General_TextCount,
-    General_ChaptersCount,
+    General_OtherCount,
     General_ImageCount,
     General_MenuCount,
     General_Video_Format_List,
@@ -184,10 +175,10 @@ enum general
     General_Text_Format_WithHint_List,
     General_Text_Codec_List,
     General_Text_Language_List,
-    General_Chapters_Format_List,
-    General_Chapters_Format_WithHint_List,
-    General_Chapters_Codec_List,
-    General_Chapters_Language_List,
+    General_Other_Format_List,
+    General_Other_Format_WithHint_List,
+    General_Other_Codec_List,
+    General_Other_Language_List,
     General_Image_Format_List,
     General_Image_Format_WithHint_List,
     General_Image_Codec_List,
@@ -200,6 +191,10 @@ enum general
     General_FolderName,
     General_FileName,
     General_FileExtension,
+    General_CompleteName_Last,
+    General_FolderName_Last,
+    General_FileName_Last,
+    General_FileExtension_Last,
     General_Format,
     General_Format_String,
     General_Format_Info,
@@ -287,7 +282,7 @@ enum general
     General_Album_Sort,
     General_Album_Performer,
     General_Album_Performer_Sort,
-    General_Album_Performe_Url,
+    General_Album_Performer_Url,
     General_Comic,
     General_Comic_More,
     General_Comic_Position_Total,
@@ -442,6 +437,7 @@ enum video
     Video_StreamKindID,
     Video_StreamKindPos,
     Video_StreamOrder,
+    Video_FirstPacketOrder,
     Video_Inform,
     Video_ID,
     Video_ID_String,
@@ -599,8 +595,12 @@ enum video
     Video_BitDepth_String,
     Video_ScanType,
     Video_ScanType_String,
+    Video_ScanType_Original,
+    Video_ScanType_Original_String,
     Video_ScanOrder,
     Video_ScanOrder_String,
+    Video_ScanOrder_Original,
+    Video_ScanOrder_Original_String,
     Video_Interlacement,
     Video_Interlacement_String,
     Video_Compression_Mode,
@@ -614,6 +614,7 @@ enum video
     Video_Delay_String3,
     Video_Delay_String4,
     Video_Delay_Settings,
+    Video_Delay_DropFrame,
     Video_Delay_Source,
     Video_Delay_Source_String,
     Video_Delay_Original,
@@ -623,7 +624,16 @@ enum video
     Video_Delay_Original_String3,
     Video_Delay_Original_String4,
     Video_Delay_Original_Settings,
+    Video_Delay_Original_DropFrame,
     Video_Delay_Original_Source,
+    Video_TimeStamp_FirstFrame,
+    Video_TimeStamp_FirstFrame_String,
+    Video_TimeStamp_FirstFrame_String1,
+    Video_TimeStamp_FirstFrame_String2,
+    Video_TimeStamp_FirstFrame_String3,
+    Video_TimeCode_FirstFrame,
+    Video_TimeCode_Settings,
+    Video_TimeCode_Source,
     Video_StreamSize,
     Video_StreamSize_String,
     Video_StreamSize_String1,
@@ -695,6 +705,7 @@ enum audio
     Audio_StreamKindID,
     Audio_StreamKindPos,
     Audio_StreamOrder,
+    Audio_FirstPacketOrder,
     Audio_Inform,
     Audio_ID,
     Audio_ID_String,
@@ -794,6 +805,8 @@ enum audio
     Audio_BitRate_Encoded_String,
     Audio_Channel_s_,
     Audio_Channel_s__String,
+    Audio_Channel_s__Original,
+    Audio_Channel_s__Original_String,
     Audio_ChannelPositions,
     Audio_ChannelPositions_String2,
     Audio_ChannelLayout,
@@ -819,6 +832,7 @@ enum audio
     Audio_Delay_String3,
     Audio_Delay_String4,
     Audio_Delay_Settings,
+    Audio_Delay_DropFrame,
     Audio_Delay_Source,
     Audio_Delay_Source_String,
     Audio_Delay_Original,
@@ -828,6 +842,7 @@ enum audio
     Audio_Delay_Original_String3,
     Audio_Delay_Original_String4,
     Audio_Delay_Original_Settings,
+    Audio_Delay_Original_DropFrame,
     Audio_Delay_Original_Source,
     Audio_Video_Delay,
     Audio_Video_Delay_String,
@@ -917,6 +932,7 @@ enum text
     Text_StreamKindID,
     Text_StreamKindPos,
     Text_StreamOrder,
+    Text_FirstPacketOrder,
     Text_Inform,
     Text_ID,
     Text_ID_String,
@@ -1025,6 +1041,7 @@ enum text
     Text_Delay_String3,
     Text_Delay_String4,
     Text_Delay_Settings,
+    Text_Delay_DropFrame,
     Text_Delay_Source,
     Text_Delay_Source_String,
     Text_Delay_Original,
@@ -1034,6 +1051,7 @@ enum text
     Text_Delay_Original_String3,
     Text_Delay_Original_String4,
     Text_Delay_Original_Settings,
+    Text_Delay_Original_DropFrame,
     Text_Delay_Original_Source,
     Text_Video_Delay,
     Text_Video_Delay_String,
@@ -1104,40 +1122,66 @@ enum text
 };
 
 //---------------------------------------------------------------------------
-enum chapters
+enum other
 {
-    Chapters_Count,
-    Chapters_StreamCount,
-    Chapters_StreamKind,
-    Chapters_StreamKind_String,
-    Chapters_StreamKindID,
-    Chapters_StreamKindPos,
-    Chapters_StreamOrder,
-    Chapters_Inform,
-    Chapters_ID,
-    Chapters_ID_String,
-    Chapters_UniqueID,
-    Chapters_MenuID,
-    Chapters_MenuID_String,
-    Chapters_Format,
-    Chapters_Format_Info,
-    Chapters_Format_Url,
-    Chapters_Codec,
-    Chapters_Codec_String,
-    Chapters_Codec_Info,
-    Chapters_Codec_Url,
-    Chapters_Total,
-    Chapters_Title,
-    Chapters_Language_String,
-    Chapters_Language_String1,
-    Chapters_Language_String2,
-    Chapters_Language_String3,
-    Chapters_Language_String4,
-    Chapters_Language_More,
-    Chapters_Default,
-    Chapters_Default_String,
-    Chapters_Forced,
-    Chapters_Forced_String,
+    Other_Count,
+    Other_Status,
+    Other_StreamCount,
+    Other_StreamKind,
+    Other_StreamKind_String,
+    Other_StreamKindID,
+    Other_StreamKindPos,
+    Other_StreamOrder,
+    Other_FirstPacketOrder,
+    Other_Inform,
+    Other_ID,
+    Other_ID_String,
+    Other_UniqueID,
+    Other_UniqueID_String,
+    Other_MenuID,
+    Other_MenuID_String,
+    Other_Type,
+    Other_Format,
+    Other_Format_Info,
+    Other_Format_Url,
+    Other_Format_Commercial,
+    Other_Format_Commercial_IfAny,
+    Other_Format_Version,
+    Other_Format_Profile,
+    Other_Format_Compression,
+    Other_Format_Settings,
+    Other_MuxingMode,
+    Other_CodecID,
+    Other_CodecID_String,
+    Other_CodecID_Info,
+    Other_CodecID_Hint,
+    Other_CodecID_Url,
+    Other_CodecID_Description,
+    Other_Duration,
+    Other_Duration_String,
+    Other_Duration_String1,
+    Other_Duration_String2,
+    Other_Duration_String3,
+    Other_Duration_Start,
+    Other_Duration_End,
+    Other_FrameRate,
+    Other_FrameRate_String,
+    Other_FrameCount,
+    Other_TimeStamp_FirstFrame,
+    Other_TimeStamp_FirstFrame_String,
+    Other_TimeStamp_FirstFrame_String1,
+    Other_TimeStamp_FirstFrame_String2,
+    Other_TimeStamp_FirstFrame_String3,
+    Other_TimeCode_FirstFrame,
+    Other_TimeCode_Settings,
+    Other_Title,
+    Other_Language,
+    Other_Language_String,
+    Other_Language_String1,
+    Other_Language_String2,
+    Other_Language_String3,
+    Other_Language_String4,
+    Other_Language_More,
 };
 
 //---------------------------------------------------------------------------
@@ -1151,6 +1195,7 @@ enum image
     Image_StreamKindID,
     Image_StreamKindPos,
     Image_StreamOrder,
+    Image_FirstPacketOrder,
     Image_Inform,
     Image_ID,
     Image_ID_String,
@@ -1252,6 +1297,7 @@ enum menu
     Menu_StreamKindID,
     Menu_StreamKindPos,
     Menu_StreamOrder,
+    Menu_FirstPacketOrder,
     Menu_Inform,
     Menu_ID,
     Menu_ID_String,
@@ -1292,6 +1338,7 @@ enum menu
     Menu_Delay_String3,
     Menu_Delay_String4,
     Menu_Delay_Settings,
+    Menu_Delay_DropFrame,
     Menu_Delay_Source,
     Menu_List_StreamKind,
     Menu_List_StreamPos,
