@@ -1,21 +1,8 @@
-// File_Dpx - Info for DPX (SMPTE 268M) files
-// Copyright (C) 2010-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -67,6 +54,7 @@ const char* DPX_Descriptors0[]=
     "Green (G)",
     "Blue (B)",
     "Alpha (matte)",
+    "", //No info
     "Luma (Y)",
     "Color Difference (CB, CR, subsampled by two)",
     "Depth (Z)",
@@ -119,42 +107,43 @@ const char* DPX_Descriptors(int8u i)
 }
 
 //---------------------------------------------------------------------------
-const char* DPX_TransferCharacteristic[]=
+const char* Mpegv_transfer_characteristics(int8u transfer_characteristics);
+const char* DPX_TransferCharacteristic(int8u TransferCharacteristic)
 {
-    "User defined",
-    "Printing density",
-    "Linear",
-    "Logarithmic",
-    "Unspecified video",
-    "SMPTE 274M",
-    "ITU-R 709-4",
-    "ITU-R 601-5 system B or G (625)",
-    "ITU-R 601-5 system M (525)",
-    "Composite video (NTSC); see SMPTE 170M",
-    "Composite video (PAL); see ITU-R 624-4",
-    "Z (depth) - linear",
-    "Z (depth) - homogeneous", //(distance to screen and angle of view must also be specified in user-defined section)
-    "Reserved for future use"
+    switch (TransferCharacteristic)
+    {
+        case  1 : return "Printing density";
+        case  2 : return Mpegv_transfer_characteristics(8);             //Linear
+        case  3 : return "Logarithmic";                                 //Value not specified in specs
+        case  5 :                                                       //SMPTE 274M, for HDTV, mapped to BT.709
+        case  6 : return Mpegv_transfer_characteristics(1);             //BT.709
+        case  7 : return Mpegv_transfer_characteristics(5);             //BT.470 System B, BT.470 System G (typo in specs?)
+        case  8 : return Mpegv_transfer_characteristics(4);             //BT.470 System M (typo in specs?)
+        case  9 :                                                       //BT.601 (NTSC)
+        case 10 : return Mpegv_transfer_characteristics(6);             //BT.601 (PAL)
+        case 11 : return "Z (depth) - linear";
+        case 12 : return "Z (depth) - homogeneous";
+        default : return "";
+    }
 };
 
 //---------------------------------------------------------------------------
-const char* DPX_ColorimetricSpecification[]=
+//---------------------------------------------------------------------------
+const char* Mpegv_colour_primaries(int8u colour_primaries);
+const char* DPX_ColorimetricSpecification(int8u ColorimetricSpecification)
 {
-    "User defined",
-    "Printing density",
-    "Not applicable",
-    "Not applicable",
-    "Unspecified video",
-    "SMPTE 274M",
-    "ITU-R 709-4",
-    "ITU-R 601-5 system B or G (625)",
-    "ITU-R 601-5 system M (525)",
-    "Composite video (NTSC); see SMPTE 170M",
-    "Composite video (PAL); see ITU-R 624-4",
-    "Not applicable",
-    "Not applicable",
-    "Reserved for future use"
-};
+    switch (ColorimetricSpecification)
+    {
+        case  1 : return "Printing density";
+        case  5 :                                                       //SMPTE 274M, for HDTV, mapped to BT.709
+        case  6 : return Mpegv_colour_primaries(1);                     //BT.709
+        case  7 : return Mpegv_colour_primaries(5);                     //BT.470 System B, BT.470 System G (typo in specs?), mapped to BT.601 PAL
+        case  8 : return Mpegv_colour_primaries(6);                     //BT.470 System M (typo in specs?), mapped to BT.601 NTSC
+        case  9 : return Mpegv_colour_primaries(6);                     //BT.601 NTSC
+        case 10 : return Mpegv_colour_primaries(5);                     //BT.601 PAL
+        default : return "";
+    }
+}
 
 //---------------------------------------------------------------------------
 const char* DPX_ValidBitDephs(int8u i)
@@ -300,7 +289,7 @@ void File_Dpx::Streams_Accept()
 
     if (!IsSub)
     {
-        Streams_Accept_TestContinuousFileNames();
+        TestContinuousFileNames();
 
         Stream_Prepare((Config->File_Names.size()>1 || Config->File_IsReferenced_Get())?Stream_Video:Stream_Image);
         Fill(StreamKind_Last, StreamPos_Last, "StreamSize", File_Size);
@@ -311,7 +300,7 @@ void File_Dpx::Streams_Accept()
         Stream_Prepare(Stream_Image);
 
     //Configuration
-    Buffer_MaximumSize=64*1024*1024;
+    Buffer_MaximumSize=64*1024*1024; //Some big frames are possible (e.g YUV 4:2:2 10 bits 1080p)
     Frame_Count_NotParsedIncluded=0;
 }
 
@@ -430,15 +419,15 @@ void File_Dpx::Data_Parse()
     do
         Sizes_Pos++; //We go automaticly to the next block
     while (Sizes_Pos<Sizes.size() && Sizes[Sizes_Pos]==0);
-    if (Sizes_Pos==Sizes.size())
+    if (Sizes_Pos>=Sizes.size())
     {
         Sizes.clear();
         Sizes_Pos=0;
 
         if (!Status[IsFilled])
             Fill();
-        if (Config_ParseSpeed<1.0)
-            Finish();
+        if (File_Offset+Buffer_Offset+Element_Size<Config->File_Current_Size)
+            GoTo(Config->File_Current_Size);
     }
 }
 
@@ -517,6 +506,8 @@ void File_Dpx::GenericSectionHeader_v1()
 
     FILLING_BEGIN();
         //Coherency tests
+        if (File_Offset+Buffer_Offset+Size_Total>=Config->File_Current_Size)
+            Size_Total=(int32u)(Config->File_Current_Size-(File_Offset+Buffer_Offset)); //The total size is bigger than the real size
         if (Size_Generic+Size_Industry+Size_User>Size_Header || Size_Header>Size_Total)
         {
             Reject();
@@ -637,8 +628,10 @@ void File_Dpx::GenericSectionHeader_v2()
 
     FILLING_BEGIN();
         //Coherency tests
+        if (File_Offset+Buffer_Offset+Size_Total!=Config->File_Current_Size)
+            Size_Total=(int32u)(Config->File_Current_Size-(File_Offset+Buffer_Offset)); //The total size is bigger than the real size
         if (Size_Generic==(int32u)-1)
-            Size_Generic=Element_Size;
+            Size_Generic=(int32u)Element_Size;
         if (Size_Industry==(int32u)-1)
             Size_Industry=0;
         if (Size_User==(int32u)-1)
@@ -680,15 +673,15 @@ void File_Dpx::GenericSectionHeader_v2()
 void File_Dpx::GenericSectionHeader_v2_ImageElement()
 {
     Element_Begin1("image element");
-    int8u BitDephs;
+    int8u TransferCharacteristic, ColorimetricSpecification, BitDephs;
     Info_B4(DataSign,                                           "Data sign");Param_Info1((DataSign==0?"unsigned":"signed"));
     Skip_B4(                                                    "Reference low data code value");
     Skip_BFP4(9,                                                "Reference low quantity represented");
     Skip_B4(                                                    "Reference high data code value");
     Skip_BFP4(9,                                                "Reference high quantity represented");
     Info_B1(Descriptor,                                         "Descriptor");Param_Info1(DPX_Descriptors(Descriptor));
-    Info_B1(TransferCharacteristic,                             "Transfer characteristic");Param_Info1(DPX_TransferCharacteristic[TransferCharacteristic]);
-    Info_B1(ColorimetricSpecification,                          "Colorimetric specification");Param_Info1(DPX_ColorimetricSpecification[ColorimetricSpecification]);
+    Get_B1 (TransferCharacteristic,                             "Transfer characteristic");Param_Info1(DPX_TransferCharacteristic(TransferCharacteristic));
+    Get_B1 (ColorimetricSpecification,                          "Colorimetric specification");Param_Info1(DPX_ColorimetricSpecification(ColorimetricSpecification));
     Get_B1 (BitDephs,                                           "Bit depth");Param_Info1(DPX_ValidBitDephs(BitDephs));
     Info_B2(ComponentDataPackingMethod,                         "Packing");Param_Info1((ComponentDataPackingMethod<8?DPX_ComponentDataPackingMethod[ComponentDataPackingMethod]:"invalid"));
     Info_B2(ComponentDataEncodingMethod,                        "Encoding");Param_Info1((ComponentDataEncodingMethod<8?DPX_ComponentDataEncodingMethod[ComponentDataEncodingMethod]:"invalid"));
@@ -704,6 +697,8 @@ void File_Dpx::GenericSectionHeader_v2_ImageElement()
             Fill(StreamKind_Last, StreamPos_Last, "Format", "DPX");
             Fill(StreamKind_Last, StreamPos_Last, "Format_Version", "Version 2");
             Fill(StreamKind_Last, StreamPos_Last, "BitDepth", BitDephs);
+            Fill(StreamKind_Last, StreamPos_Last, "colour_primaries", DPX_TransferCharacteristic(TransferCharacteristic));
+            Fill(StreamKind_Last, StreamPos_Last, "transfer_characteristics", DPX_ColorimetricSpecification(ColorimetricSpecification));
         }
     FILLING_END();
 }
@@ -819,6 +814,9 @@ void File_Dpx::ImageData()
     Frame_Count++;
     if (Frame_Count_NotParsedIncluded!=(int64u)-1)
         Frame_Count_NotParsedIncluded++;
+
+    if (Config->ParseSpeed<1.0)
+        Finish("DPX"); //No need of more
 }
 
 //***************************************************************************
