@@ -1,20 +1,9 @@
-// MediaInfo_Config - Configuration class
-// Copyright (C) 2005-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Global configuration of MediaInfo
@@ -45,8 +34,8 @@ namespace MediaInfoLib
 {
 
 //---------------------------------------------------------------------------
-const Char*  MediaInfo_Version=__T("MediaInfoLib - v0.7.59");
-const Char*  MediaInfo_Url=__T("http://mediainfo.sourceforge.net");
+const Char*  MediaInfo_Version=__T("MediaInfoLib - v0.7.64");
+const Char*  MediaInfo_Url=__T("http://MediaArea.net/MediaInfo");
       Ztring EmptyZtring;       //Use it when we can't return a reference to a true Ztring
 const Ztring EmptyZtring_Const; //Use it when we can't return a reference to a true Ztring, const version
 const ZtringListList EmptyZtringListList_Const; //Use it when we can't return a reference to a true ZtringListList, const version
@@ -75,7 +64,7 @@ void MediaInfo_Config_General                 (ZtringListList &Info);
 void MediaInfo_Config_Video                   (ZtringListList &Info);
 void MediaInfo_Config_Audio                   (ZtringListList &Info);
 void MediaInfo_Config_Text                    (ZtringListList &Info);
-void MediaInfo_Config_Chapters                (ZtringListList &Info);
+void MediaInfo_Config_Other                   (ZtringListList &Info);
 void MediaInfo_Config_Image                   (ZtringListList &Info);
 void MediaInfo_Config_Menu                    (ZtringListList &Info);
 void MediaInfo_Config_Summary                 (ZtringListList &Info);
@@ -108,9 +97,20 @@ void MediaInfo_Config::Init()
 
     //Filling
     FormatDetection_MaximumOffset=0;
-    MpegTs_MaximumOffset=32*1024*1024;
-    MpegTs_MaximumScanDuration=16000000000LL;
+    #if MEDIAINFO_ADVANCED
+        VariableGopDetection_Occurences=4;
+        VariableGopDetection_GiveUp=false;
+        InitDataNotRepeated_Occurences=(int64u)-1; //Disabled by default
+        InitDataNotRepeated_GiveUp=false;
+    #endif //MEDIAINFO_ADVANCED
+    MpegTs_MaximumOffset=64*1024*1024;
+    MpegTs_MaximumScanDuration=30000000000LL;
     MpegTs_ForceStreamDisplay=false;
+    #if MEDIAINFO_ADVANCED
+        MpegTs_VbrDetection_Delta=0;
+        MpegTs_VbrDetection_Occurences=4;
+        MpegTs_VbrDetection_GiveUp=false;
+    #endif //MEDIAINFO_ADVANCED
     Complete=0;
     BlockMethod=0;
     Internet=0;
@@ -129,6 +129,7 @@ void MediaInfo_Config::Init()
     Language_Raw=false;
     ReadByHuman=true;
     LegacyStreamDisplay=true;
+    SkipBinaryData=false;
     Demux=0;
     LineSeparator=EOL;
     ColumnSeparator=__T(";");
@@ -326,6 +327,15 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     {
         return LegacyStreamDisplay_Get()?__T("1"):__T("0");
     }
+    else if (Option_Lower==__T("skipbinarydata"))
+    {
+        SkipBinaryData_Set(Value.To_int8u()?true:false);
+        return Ztring();
+    }
+    else if (Option_Lower==__T("skipbinarydata_get"))
+    {
+        return SkipBinaryData_Get()?__T("1"):__T("0");
+    }
     else if (Option_Lower==__T("parsespeed"))
     {
         ParseSpeed_Set(Value.To_float32());
@@ -452,7 +462,7 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     }
     else if (Option_Lower==__T("inform_replace_get"))
     {
-        return Inform_Replace_Get();
+        return Inform_Get();
     }
     else if (Option_Lower==__T("details")) //Legacy for trace_level
     {
@@ -547,7 +557,7 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     }
     else if (Option_Lower==__T("info_parameters_csv"))
     {
-        return Info_Parameters_Get();
+        return Info_Parameters_Get(Value==__T("Complete"));
     }
     else if (Option_Lower==__T("info_codecs"))
     {
@@ -570,6 +580,74 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     {
         return FormatDetection_MaximumOffset_Get()==(int64u)-1?Ztring(__T("-1")):Ztring::ToZtring(FormatDetection_MaximumOffset_Get());
     }
+    else if (Option_Lower==__T("variablegopdetection_occurences"))
+    {
+        #if MEDIAINFO_ADVANCED
+            VariableGopDetection_Occurences_Set(Value.To_int64u());
+            return Ztring();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("variablegopdetection_occurences_get"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return Ztring::ToZtring(VariableGopDetection_Occurences_Get());
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("variablegopdetection_giveup"))
+    {
+        #if MEDIAINFO_ADVANCED
+            VariableGopDetection_GiveUp_Set(Value.To_int8u()?true:false);
+            return Ztring();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("variablegopdetection_giveup_get"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return VariableGopDetection_GiveUp_Get()?__T("1"):__T("0");
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("initdatanotrepeated_occurences"))
+    {
+        #if MEDIAINFO_ADVANCED
+            InitDataNotRepeated_Occurences_Set(Value.To_int64u());
+            return Ztring();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("initdatanotrepeated_occurences_get"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return Ztring::ToZtring(InitDataNotRepeated_Occurences_Get());
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("initdatanotrepeated_giveup"))
+    {
+        #if MEDIAINFO_ADVANCED
+            InitDataNotRepeated_GiveUp_Set(Value.To_int8u()?true:false);
+            return Ztring();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("initdatanotrepeated_giveup_get"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return InitDataNotRepeated_GiveUp_Get()?__T("1"):__T("0");
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
     else if (Option_Lower==__T("mpegts_maximumoffset"))
     {
         MpegTs_MaximumOffset_Set(Value==__T("-1")?(int64u)-1:((Ztring*)&Value)->To_int64u());
@@ -579,6 +657,57 @@ Ztring MediaInfo_Config::Option (const String &Option, const String &Value_Raw)
     {
         return MpegTs_MaximumOffset_Get()==(int64u)-1?Ztring(__T("-1")):Ztring::ToZtring(MpegTs_MaximumOffset_Get());
     }
+    else if (Option_Lower==__T("mpegts_vbrdetection_delta"))
+    {
+        #if MEDIAINFO_ADVANCED
+            MpegTs_VbrDetection_Delta_Set(Value.To_float64());
+            return Ztring();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("mpegts_vbrdetection_delta_get"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return Ztring::ToZtring(MpegTs_VbrDetection_Delta_Get(), 9);
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("mpegts_vbrdetection_occurences"))
+    {
+        #if MEDIAINFO_ADVANCED
+            MpegTs_VbrDetection_Occurences_Set(Value.To_int64u());
+            return Ztring();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("mpegts_vbrdetection_occurences_get"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return Ztring::ToZtring(MpegTs_VbrDetection_Occurences_Get());
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("mpegts_vbrdetection_giveup"))
+    {
+        #if MEDIAINFO_ADVANCED
+            MpegTs_VbrDetection_GiveUp_Set(Value.To_int8u()?true:false);
+            return Ztring();
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
+    else if (Option_Lower==__T("mpegts_vbrdetection_giveup_get"))
+    {
+        #if MEDIAINFO_ADVANCED
+            return MpegTs_VbrDetection_GiveUp_Get()?__T("1"):__T("0");
+        #else // MEDIAINFO_ADVANCED
+            return __T("advanced features are disabled due to compilation options");
+        #endif // MEDIAINFO_ADVANCED
+    }
     else if (Option_Lower==__T("mpegts_maximumscanduration"))
     {
         MpegTs_MaximumScanDuration_Set(float64_int64s((((Ztring*)&Value)->To_float64())*1000000000));
@@ -893,6 +1022,19 @@ bool MediaInfo_Config::LegacyStreamDisplay_Get ()
     return LegacyStreamDisplay;
 }
 
+//---------------------------------------------------------------------------
+void MediaInfo_Config::SkipBinaryData_Set (bool NewValue)
+{
+    CriticalSectionLocker CSL(CS);
+    SkipBinaryData=NewValue;
+}
+
+bool MediaInfo_Config::SkipBinaryData_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return SkipBinaryData;
+}
+
 //---------------------------------------------------------------------------
 void MediaInfo_Config::Trace_Level_Set (const ZtringListList &NewTrace_Level)
 {
@@ -1381,12 +1523,6 @@ void MediaInfo_Config::Inform_Replace_Set (const ZtringListList &NewValue_Replac
     }
 }
 
-Ztring MediaInfo_Config::Inform_Replace_Get ()
-{
-    CriticalSectionLocker CSL(CS);
-    return Custom_View.Read();
-}
-
 ZtringListList MediaInfo_Config::Inform_Replace_Get_All ()
 {
     CriticalSectionLocker CSL(CS);
@@ -1447,7 +1583,7 @@ const Ztring &MediaInfo_Config::Codec_Get (const Ztring &Value, infocodec_t Kind
         case Stream_Audio    : KindOfStreamS=__T("A"); break;
         case Stream_Text     : KindOfStreamS=__T("T"); break;
         case Stream_Image    : KindOfStreamS=__T("I"); break;
-        case Stream_Chapters : KindOfStreamS=__T("C"); break;
+        case Stream_Other : KindOfStreamS=__T("C"); break;
         case Stream_Menu     : KindOfStreamS=__T("M"); break;
         case Stream_Max      : KindOfStreamS=__T(" "); break;
     }
@@ -1563,7 +1699,7 @@ const Ztring MediaInfo_Config::Iso639_Find (const Ztring &Value)
     Ztring Value_Lower(Value);
     Value_Lower.MakeLowerCase();
 
-    for (Translation::iterator Trans=Info.begin(); Trans!=Info.end(); Trans++)
+    for (Translation::iterator Trans=Info.begin(); Trans!=Info.end(); ++Trans)
     {
         Trans->second.MakeLowerCase();
         if (Trans->second==Value_Lower && Trans->first.find(__T("Language_"))==0)
@@ -1584,7 +1720,7 @@ const Ztring &MediaInfo_Config::Info_Get (stream_t KindOfStream, const Ztring &V
             case Stream_Video :     MediaInfo_Config_Video(Info[Stream_Video]);       Language_Set(Stream_Video); break;
             case Stream_Audio :     MediaInfo_Config_Audio(Info[Stream_Audio]);       Language_Set(Stream_Audio); break;
             case Stream_Text :      MediaInfo_Config_Text(Info[Stream_Text]);         Language_Set(Stream_Text); break;
-            case Stream_Chapters :  MediaInfo_Config_Chapters(Info[Stream_Chapters]); Language_Set(Stream_Chapters); break;
+            case Stream_Other :     MediaInfo_Config_Other(Info[Stream_Other]);       Language_Set(Stream_Other); break;
             case Stream_Image :     MediaInfo_Config_Image(Info[Stream_Image]);       Language_Set(Stream_Image); break;
             case Stream_Menu :      MediaInfo_Config_Menu(Info[Stream_Menu]);         Language_Set(Stream_Menu); break;
             default:;
@@ -1610,7 +1746,7 @@ const Ztring &MediaInfo_Config::Info_Get (stream_t KindOfStream, size_t Pos, inf
             case Stream_Video :     MediaInfo_Config_Video(Info[Stream_Video]);       Language_Set(Stream_Video); break;
             case Stream_Audio :     MediaInfo_Config_Audio(Info[Stream_Audio]);       Language_Set(Stream_Audio); break;
             case Stream_Text :      MediaInfo_Config_Text(Info[Stream_Text]);         Language_Set(Stream_Text); break;
-            case Stream_Chapters :  MediaInfo_Config_Chapters(Info[Stream_Chapters]); Language_Set(Stream_Chapters); break;
+            case Stream_Other :     MediaInfo_Config_Other(Info[Stream_Other]);       Language_Set(Stream_Other); break;
             case Stream_Image :     MediaInfo_Config_Image(Info[Stream_Image]);       Language_Set(Stream_Image); break;
             case Stream_Menu :      MediaInfo_Config_Menu(Info[Stream_Menu]);         Language_Set(Stream_Menu); break;
             default:;
@@ -1638,7 +1774,7 @@ const ZtringListList &MediaInfo_Config::Info_Get(stream_t KindOfStream)
             case Stream_Video :     MediaInfo_Config_Video(Info[Stream_Video]);       Language_Set(Stream_Video); break;
             case Stream_Audio :     MediaInfo_Config_Audio(Info[Stream_Audio]);       Language_Set(Stream_Audio); break;
             case Stream_Text :      MediaInfo_Config_Text(Info[Stream_Text]);         Language_Set(Stream_Text); break;
-            case Stream_Chapters :  MediaInfo_Config_Chapters(Info[Stream_Chapters]); Language_Set(Stream_Chapters); break;
+            case Stream_Other :     MediaInfo_Config_Other(Info[Stream_Other]);       Language_Set(Stream_Other); break;
             case Stream_Image :     MediaInfo_Config_Image(Info[Stream_Image]);       Language_Set(Stream_Image); break;
             case Stream_Menu :      MediaInfo_Config_Menu(Info[Stream_Menu]);         Language_Set(Stream_Menu); break;
             default:;
@@ -1649,7 +1785,7 @@ const ZtringListList &MediaInfo_Config::Info_Get(stream_t KindOfStream)
 }
 
 //---------------------------------------------------------------------------
-Ztring MediaInfo_Config::Info_Parameters_Get ()
+Ztring MediaInfo_Config::Info_Parameters_Get (bool Complete)
 {
     CriticalSectionLocker CSL(CS);
 
@@ -1658,7 +1794,7 @@ Ztring MediaInfo_Config::Info_Parameters_Get ()
     MediaInfo_Config_Video(Info[Stream_Video]);
     MediaInfo_Config_Audio(Info[Stream_Audio]);
     MediaInfo_Config_Text(Info[Stream_Text]);
-    MediaInfo_Config_Chapters(Info[Stream_Chapters]);
+    MediaInfo_Config_Other(Info[Stream_Other]);
     MediaInfo_Config_Image(Info[Stream_Image]);
     MediaInfo_Config_Menu(Info[Stream_Menu]);
 
@@ -1673,8 +1809,13 @@ Ztring MediaInfo_Config::Info_Parameters_Get ()
         for (size_t Pos=0; Pos<Info[StreamKind].size(); Pos++)
             if (!Info[StreamKind].Read(Pos, Info_Name).empty())
             {
-                ToReturn(ToReturn_Pos, 0)=Info[StreamKind].Read(Pos, Info_Name);
-                ToReturn(ToReturn_Pos, 1)=Info[StreamKind].Read(Pos, Info_Info);
+                if (Complete)
+                    ToReturn.push_back(Info[StreamKind].Read(Pos));
+                else
+                {
+                    ToReturn(ToReturn_Pos, 0)=Info[StreamKind].Read(Pos, Info_Name);
+                    ToReturn(ToReturn_Pos, 1)=Info[StreamKind].Read(Pos, Info_Info);
+                }
                 ToReturn_Pos++;
             }
         ToReturn_Pos++;
@@ -1702,7 +1843,7 @@ Ztring MediaInfo_Config::Info_Codecs_Get ()
     {
         ToReturn+=Temp->second.Read();
         ToReturn+=EOL;
-        Temp++;
+        ++Temp;
     }
 
     return ToReturn;
@@ -1740,6 +1881,62 @@ int64u MediaInfo_Config::FormatDetection_MaximumOffset_Get ()
     return FormatDetection_MaximumOffset;
 }
 
+#if MEDIAINFO_ADVANCED
+void MediaInfo_Config::VariableGopDetection_Occurences_Set (int64u Value)
+{
+    CriticalSectionLocker CSL(CS);
+    VariableGopDetection_Occurences=Value;
+}
+
+int64u MediaInfo_Config::VariableGopDetection_Occurences_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return VariableGopDetection_Occurences;
+}
+#endif // MEDIAINFO_ADVANCED
+
+#if MEDIAINFO_ADVANCED
+void MediaInfo_Config::VariableGopDetection_GiveUp_Set (bool Value)
+{
+    CriticalSectionLocker CSL(CS);
+    VariableGopDetection_GiveUp=Value;
+}
+
+bool MediaInfo_Config::VariableGopDetection_GiveUp_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return VariableGopDetection_GiveUp;
+}
+#endif // MEDIAINFO_ADVANCED
+
+#if MEDIAINFO_ADVANCED
+void MediaInfo_Config::InitDataNotRepeated_Occurences_Set (int64u Value)
+{
+    CriticalSectionLocker CSL(CS);
+    InitDataNotRepeated_Occurences=Value;
+}
+
+int64u MediaInfo_Config::InitDataNotRepeated_Occurences_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return InitDataNotRepeated_Occurences;
+}
+#endif // MEDIAINFO_ADVANCED
+
+#if MEDIAINFO_ADVANCED
+void MediaInfo_Config::InitDataNotRepeated_GiveUp_Set (bool Value)
+{
+    CriticalSectionLocker CSL(CS);
+    InitDataNotRepeated_GiveUp=Value;
+}
+
+bool MediaInfo_Config::InitDataNotRepeated_GiveUp_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return InitDataNotRepeated_GiveUp;
+}
+#endif // MEDIAINFO_ADVANCED
+
 void MediaInfo_Config::MpegTs_MaximumOffset_Set (int64u Value)
 {
     CriticalSectionLocker CSL(CS);
@@ -1764,6 +1961,48 @@ int64u MediaInfo_Config::MpegTs_MaximumScanDuration_Get ()
     return MpegTs_MaximumScanDuration;
 }
 
+#if MEDIAINFO_ADVANCED
+void MediaInfo_Config::MpegTs_VbrDetection_Delta_Set (float64 Value)
+{
+    CriticalSectionLocker CSL(CS);
+    MpegTs_VbrDetection_Delta=Value;
+}
+
+float64 MediaInfo_Config::MpegTs_VbrDetection_Delta_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return MpegTs_VbrDetection_Delta;
+}
+#endif // MEDIAINFO_ADVANCED
+
+#if MEDIAINFO_ADVANCED
+void MediaInfo_Config::MpegTs_VbrDetection_Occurences_Set (int64u Value)
+{
+    CriticalSectionLocker CSL(CS);
+    MpegTs_VbrDetection_Occurences=Value;
+}
+
+int64u MediaInfo_Config::MpegTs_VbrDetection_Occurences_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return MpegTs_VbrDetection_Occurences;
+}
+#endif // MEDIAINFO_ADVANCED
+
+#if MEDIAINFO_ADVANCED
+void MediaInfo_Config::MpegTs_VbrDetection_GiveUp_Set (bool Value)
+{
+    CriticalSectionLocker CSL(CS);
+    MpegTs_VbrDetection_GiveUp=Value;
+}
+
+bool MediaInfo_Config::MpegTs_VbrDetection_GiveUp_Get ()
+{
+    CriticalSectionLocker CSL(CS);
+    return MpegTs_VbrDetection_GiveUp;
+}
+#endif // MEDIAINFO_ADVANCED
+
 void MediaInfo_Config::MpegTs_ForceStreamDisplay_Set (bool Value)
 {
     CriticalSectionLocker CSL(CS);
@@ -2072,4 +2311,3 @@ bool MediaInfo_Config::Ssl_IgnoreSecurity_Get ()
 #endif //defined(MEDIAINFO_LIBCURL_YES)
 
 } //NameSpace
-
