@@ -1,21 +1,8 @@
-// File_Gxf - Info for GXF (SMPTE 360M) files
-// Copyright (C) 2010-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -51,7 +38,10 @@
 #if defined(MEDIAINFO_AC3_YES)
     #include "MediaInfo/Audio/File_Ac3.h"
 #endif
-#if defined(MEDIAINFO_AES3_YES)
+#if defined(MEDIAINFO_PCM_YES)
+    #include "MediaInfo/Audio/File_Pcm.h"
+#endif
+#if defined(MEDIAINFO_SMPTEST0337_YES)
     #include "MediaInfo/Audio/File_ChannelGrouping.h"
 #endif
 #if MEDIAINFO_EVENTS
@@ -322,12 +312,12 @@ void File_Gxf::Streams_Finish()
                     if (Streams[StreamID2].MediaName==Title+__T(".A")+Ztring::ToZtring(StreamID2-StreamID))
                     {
                         Streams[StreamID].MediaName=Title;
-                        if (Streams[StreamID].Parser && Streams[StreamID2].Parser)
+                        if (Streams[StreamID].Parsers.size()==1 && Streams[StreamID2].Parsers.size()==1)
                         {
-                            int32u Channels=Streams[StreamID].Parser->Retrieve(Stream_Audio, 0, Audio_Channel_s_).To_int32u()+Streams[StreamID2].Parser->Retrieve(Stream_Audio, 0, Audio_Channel_s_).To_int32u();
-                            Streams[StreamID].Parser->Fill(Stream_Audio, 0, Audio_Channel_s_, Channels, 10, true);
-                            int32u BitRate=Streams[StreamID].Parser->Retrieve(Stream_Audio, 0, Audio_BitRate).To_int32u()+Streams[StreamID2].Parser->Retrieve(Stream_Audio, 0, Audio_BitRate).To_int32u();
-                            Streams[StreamID].Parser->Fill(Stream_Audio, 0, Audio_BitRate, BitRate, 10, true);
+                            int32u Channels=Streams[StreamID].Parsers[0]->Retrieve(Stream_Audio, 0, Audio_Channel_s_).To_int32u()+Streams[StreamID2].Parsers[0]->Retrieve(Stream_Audio, 0, Audio_Channel_s_).To_int32u();
+                            Streams[StreamID].Parsers[0]->Fill(Stream_Audio, 0, Audio_Channel_s_, Channels, 10, true);
+                            int32u BitRate=Streams[StreamID].Parsers[0]->Retrieve(Stream_Audio, 0, Audio_BitRate).To_int32u()+Streams[StreamID2].Parsers[0]->Retrieve(Stream_Audio, 0, Audio_BitRate).To_int32u();
+                            Streams[StreamID].Parsers[0]->Fill(Stream_Audio, 0, Audio_BitRate, BitRate, 10, true);
                         }
                         Streams[StreamID2].MediaType=(int8u)-1;
                     }
@@ -357,6 +347,33 @@ void File_Gxf::Streams_Finish()
     {
         //Fill(Stream_General, 0, General_OverallBitRate, ((int64u)Material_File_Size)*1024*8/???);
     }
+
+    //Time code tracks
+    for (std::map<int8u, tc>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); ++TimeCode)
+    {
+        int64u TimeCode_FirstFrame_ms=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parsers[0])->TimeCode_FirstFrame_ms;
+        string TimeCode_FirstFrame=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parsers[0])->TimeCode_FirstFrame;
+        bool   TimeCode_FirstFrame_Striped=false;
+        if (TimeCode_FirstFrame_ms==(int64u)-1)
+        {
+            TimeCode_FirstFrame_ms=TimeCode->second.Milliseconds;
+            TimeCode_FirstFrame=TimeCode->second.String;
+            TimeCode_FirstFrame_Striped=true;
+        }
+        if (TimeCode_FirstFrame_ms!=(int64u)-1)
+        {
+            Stream_Prepare(Stream_Other);
+            Fill(Stream_Other, StreamPos_Last, Other_ID, TimeCode->first);
+            Fill(Stream_Other, StreamPos_Last, Other_Type, "Time code");
+            Fill(Stream_Other, StreamPos_Last, Other_Format, "SMPTE TC");
+            //Fill(Stream_Other, StreamPos_Last, Other_MuxingMode, "Time code track");
+            Fill(Stream_Other, StreamPos_Last, Other_TimeCode_FirstFrame, TimeCode_FirstFrame.c_str());
+            if (TimeCode_FirstFrame_Striped)
+                Fill(Stream_Other, StreamPos_Last, Other_TimeCode_Settings, "Striped");
+            if (TimeCode->first<Streams.size())
+                Fill(Stream_Other, StreamPos_Last, Other_Title, Streams[TimeCode->first].MediaName);
+        }
+    }
 }
 
 //---------------------------------------------------------------------------
@@ -366,25 +383,25 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
         return;
 
     //By the parser
-    if (Temp.Parser && Temp.Parser->Status[IsAccepted])
+    if (Temp.Parsers.size()==1 && Temp.Parsers[0]->Status[IsAccepted])
     {
         StreamKind_Last=Stream_Max;
         StreamPos_Last=(size_t)-1;
-        if (Config_ParseSpeed<=1.0)
+        if (Config->ParseSpeed<=1.0)
         {
-            Fill(Temp.Parser);
-            Temp.Parser->Open_Buffer_Unsynch();
+            Fill(Temp.Parsers[0]);
+            Temp.Parsers[0]->Open_Buffer_Unsynch();
         }
-        Finish(Temp.Parser);
+        Finish(Temp.Parsers[0]);
 
         //Video
         bool IsTimeCode=false;
-        for (std::map<int8u, int64u>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); TimeCode++)
+        for (std::map<int8u, tc>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); ++TimeCode)
             if (StreamID==TimeCode->first)
                 IsTimeCode=true;
         if (!IsTimeCode && Temp.DisplayInfo)
         {
-            if (Temp.Parser->Count_Get(Stream_Video))
+            if (Temp.Parsers[0]->Count_Get(Stream_Video))
             {
                 Stream_Prepare(Stream_Video);
 
@@ -394,32 +411,41 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                     Fill(Stream_Video, StreamPos_Last, Video_Delay_Source, "Container");
                 }
                 else
-                    for (std::map<int8u, int64u>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); TimeCode++)
+                    for (std::map<int8u, tc>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); ++TimeCode)
                     {
-                        int64u TimeCode_First=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parser)->TimeCode_First;
-                        if (TimeCode_First==(int64u)-1)
-                            TimeCode_First=TimeCode->second;
-                        if (TimeCode_First!=(int64u)-1)
+                        int64u TimeCode_FirstFrame_ms=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parsers[0])->TimeCode_FirstFrame_ms;
+                        string TimeCode_FirstFrame=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parsers[0])->TimeCode_FirstFrame;
+                        if (TimeCode_FirstFrame_ms==(int64u)-1)
                         {
-                            Fill(Stream_Video, StreamPos_Last, Video_Delay, TimeCode_First, 0);
+                            TimeCode_FirstFrame_ms=TimeCode->second.Milliseconds;
+                            TimeCode_FirstFrame=TimeCode->second.String;
+                        }
+                        if (TimeCode_FirstFrame_ms!=(int64u)-1)
+                        {
+                            Fill(Stream_Video, StreamPos_Last, Video_Delay, TimeCode_FirstFrame_ms, 0);
+                            if (TimeCode_FirstFrame.size()==11)
+                                Fill(Stream_Video, StreamPos_Last, Video_Delay_DropFrame, TimeCode_FirstFrame[8]==';'?"Yes":"No");
                             Fill(Stream_Video, StreamPos_Last, Video_Delay_Source, "Container");
+
+                            //Fill(Stream_Video, StreamPos_Last, Video_TimeCode_FirstFrame, TimeCode_FirstFrame.c_str());
+                            //Fill(Stream_Video, StreamPos_Last, Video_TimeCode_Source, "Time code track");
                         }
                     }
 
-                Merge(*Temp.Parser, Stream_Video, 0, StreamPos_Last);
+                Merge(*Temp.Parsers[0], Stream_Video, 0, StreamPos_Last);
 
                 Fill(Stream_Video, StreamPos_Last, Video_ID, StreamID, 10, true);
                 Fill(Stream_Video, StreamPos_Last, "Title", Temp.MediaName);
 
                 //Special cases
-                if (Temp.Parser->Count_Get(Stream_Text))
+                if (Temp.Parsers[0]->Count_Get(Stream_Text))
                 {
                     //Video and Text are together
-                    size_t Parser_Text_Count=Temp.Parser->Count_Get(Stream_Text);
+                    size_t Parser_Text_Count=Temp.Parsers[0]->Count_Get(Stream_Text);
                     for (size_t Parser_Text_Pos=0; Parser_Text_Pos<Parser_Text_Count; Parser_Text_Pos++)
                     {
                         Stream_Prepare(Stream_Text);
-                        Merge(*Temp.Parser, Stream_Text, Parser_Text_Pos, StreamPos_Last);
+                        Merge(*Temp.Parsers[0], Stream_Text, Parser_Text_Pos, StreamPos_Last);
                         Ztring ID=Retrieve(Stream_Text, StreamPos_Last, Text_ID);
                         Fill(Stream_Text, StreamPos_Last, Text_ID, Ztring::ToZtring(AncillaryData_StreamID)+__T("-")+ID, true);
                         Fill(Stream_Text, StreamPos_Last, Text_ID_String, Ztring::ToZtring(AncillaryData_StreamID)+__T("-")+ID, true);
@@ -435,7 +461,7 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
             }
 
             //Audio
-            for (size_t Pos=0; Pos<Temp.Parser->Count_Get(Stream_Audio); Pos++)
+            for (size_t Pos=0; Pos<Temp.Parsers[0]->Count_Get(Stream_Audio); Pos++)
             {
                 Stream_Prepare(Stream_Audio);
 
@@ -445,20 +471,33 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                     Fill(Stream_Audio, StreamPos_Last, Audio_Delay_Source, "Container");
                 }
                 else
-                    for (std::map<int8u, int64u>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); TimeCode++)
+                    for (std::map<int8u, tc>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); ++TimeCode)
                     {
-                        int64u TimeCode_First=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parser)->TimeCode_First;
-                        if (TimeCode_First==(int64u)-1)
-                            TimeCode_First=TimeCode->second;
-                        Fill(Stream_Audio, StreamPos_Last, Audio_Delay, TimeCode_First, 0);
-                        Fill(Stream_Audio, StreamPos_Last, Audio_Delay_Source, "Container");
+                        int64u TimeCode_FirstFrame_ms=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parsers[0])->TimeCode_FirstFrame_ms;
+                        string TimeCode_FirstFrame=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parsers[0])->TimeCode_FirstFrame;
+                        if (TimeCode_FirstFrame_ms==(int64u)-1)
+                        {
+                            TimeCode_FirstFrame_ms=TimeCode->second.Milliseconds;
+                            TimeCode_FirstFrame=TimeCode->second.String;
+                        }
+                        if (TimeCode_FirstFrame_ms!=(int64u)-1)
+                        {
+                            Fill(Stream_Audio, StreamPos_Last, Audio_Delay, TimeCode_FirstFrame_ms, 0);
+                            if (TimeCode_FirstFrame.size()==11)
+                                Fill(Stream_Audio, StreamPos_Last, Audio_Delay_DropFrame, TimeCode_FirstFrame[8]==';'?"Yes":"No");
+                            Fill(Stream_Audio, StreamPos_Last, Audio_Delay_Source, "Container");
+
+                            //Fill(Stream_Audio, StreamPos_Last, Audio_TimeCode_FirstFrame, TimeCode_FirstFrame.c_str());
+                            //Fill(Stream_Audio, StreamPos_Last, Audio_TimeCode_Source, "Time code track");
+                        }
                     }
 
-                Merge(*Temp.Parser, Stream_Audio, Pos, StreamPos_Last, false);
+                Merge(*Temp.Parsers[0], Stream_Audio, Pos, StreamPos_Last, false);
 
-                Ztring ID=Ztring::ToZtring(StreamID);
+                Ztring ID;
                 if (Temp.IsChannelGrouping)
-                    ID+=__T(" / ")+Ztring::ToZtring(StreamID+1); //Second half of the channel grouping
+                    ID=Ztring::ToZtring(StreamID-1)+__T(" / "); //First half of the channel grouping
+                ID+=Ztring::ToZtring(StreamID); //Second half of the channel grouping or standalone
                 Ztring ID_String=ID;
                 if (!Retrieve(Stream_Audio, StreamPos_Last, Audio_ID).empty())
                 {
@@ -467,23 +506,25 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                 }
                 Fill(Stream_Audio, StreamPos_Last, Audio_ID, ID, true);
                 Fill(Stream_Audio, StreamPos_Last, Audio_ID_String, ID_String, true);
-                Fill(Stream_Audio, StreamPos_Last, "Title", Temp.MediaName);
                 if (Temp.IsChannelGrouping)
-                    Fill(StreamKind_Last, StreamPos_Last, "Title", Streams[StreamID+1].MediaName); //Second half of the channel grouping
+                    Fill(Stream_Audio, StreamPos_Last, "Title", Streams[StreamID-1].MediaName); //First half of the channel grouping
+                Fill(StreamKind_Last, StreamPos_Last, "Title", Temp.MediaName); //Second half of the channel grouping or standalone
 
-                for (std::map<std::string, Ztring>::iterator Info=Temp.Infos.begin(); Info!=Temp.Infos.end(); Info++)
-                    if (Retrieve(Stream_Audio, StreamPos_Last, Info->first.c_str()).empty())
+                for (std::map<std::string, Ztring>::iterator Info=Temp.Infos.begin(); Info!=Temp.Infos.end(); ++Info)
+                    if (Info->first=="BitRate" && Temp.Parsers[0]->Count_Get(Stream_Audio)>1)
+                        Fill(Stream_Audio, StreamPos_Last, Audio_BitRate_Encoded, Pos?Ztring(__T("0")):Info->second); // In case of more than 1 audio sub-stream Encoded bit rate is the bit rate of all streams + overhead
+                    else if (Retrieve(Stream_Audio, StreamPos_Last, Info->first.c_str()).empty())
                         Fill(Stream_Audio, StreamPos_Last, Info->first.c_str(), Info->second);
             }
 
             //Text
-            if (Temp.Parser->Count_Get(Stream_Text))
+            if (Temp.Parsers[0]->Count_Get(Stream_Text))
             {
-                size_t Parser_Text_Count=Temp.Parser->Count_Get(Stream_Text);
+                size_t Parser_Text_Count=Temp.Parsers[0]->Count_Get(Stream_Text);
                 for (size_t Parser_Text_Pos=0; Parser_Text_Pos<Parser_Text_Count; Parser_Text_Pos++)
                 {
                     Stream_Prepare(Stream_Text);
-                    Merge(*Temp.Parser, Stream_Text, Parser_Text_Pos, StreamPos_Last);
+                    Merge(*Temp.Parsers[0], Stream_Text, Parser_Text_Pos, StreamPos_Last);
                     Ztring ID=Retrieve(Stream_Text, StreamPos_Last, Text_ID);
                     Fill(Stream_Text, StreamPos_Last, Text_ID, Ztring::ToZtring(AncillaryData_StreamID)+__T("-")+ID, true);
                     Fill(Stream_Text, StreamPos_Last, Text_ID_String, Ztring::ToZtring(AncillaryData_StreamID)+__T("-")+ID, true);
@@ -497,6 +538,30 @@ void File_Gxf::Streams_Finish_PerStream(size_t StreamID, stream &Temp)
                 StreamKind_Last=Stream_Max;
                 StreamPos_Last=(size_t)-1;
             }
+
+            //Other
+            if (Temp.Parsers[0]->Count_Get(Stream_Other))
+            {
+                size_t Parser_Other_Count=Temp.Parsers[0]->Count_Get(Stream_Other);
+                for (size_t Parser_Other_Pos=0; Parser_Other_Pos<Parser_Other_Count; Parser_Other_Pos++)
+                {
+                    Stream_Prepare(Stream_Other);
+                    Merge(*Temp.Parsers[0], Stream_Other, Parser_Other_Pos, StreamPos_Last);
+                    Ztring ID=Retrieve(Stream_Other, StreamPos_Last, Other_ID);
+                    Fill(Stream_Other, StreamPos_Last, Other_ID, Ztring::ToZtring(AncillaryData_StreamID)+__T("-")+ID, true);
+                    Fill(Stream_Other, StreamPos_Last, Other_ID_String, Ztring::ToZtring(AncillaryData_StreamID)+__T("-")+ID, true);
+                    /*
+                    Fill(Stream_Other, StreamPos_Last, Other_Delay, Retrieve(Stream_Video, Count_Get(Stream_Video)-1, Video_Delay), true);
+                    Fill(Stream_Other, StreamPos_Last, Other_Delay_Source, Retrieve(Stream_Video, Count_Get(Stream_Video)-1, Video_Delay_Source), true);
+                    Fill(Stream_Other, StreamPos_Last, Other_Delay_Original, Retrieve(Stream_Video, Count_Get(Stream_Video)-1, Video_Delay_Original), true);
+                    Fill(Stream_Other, StreamPos_Last, Other_Delay_Original_Source, Retrieve(Stream_Video, Count_Get(Stream_Video)-1, Video_Delay_Original_Source), true);
+                    */
+                    Fill(Stream_Other, StreamPos_Last, "Title", Temp.MediaName);
+                }
+
+                StreamKind_Last=Stream_Max;
+                StreamPos_Last=(size_t)-1;
+            }
         }
     }
 }
@@ -600,8 +665,8 @@ bool File_Gxf::Synched_Test()
 void File_Gxf::Read_Buffer_Unsynched()
 {
     for (size_t Pos=0; Pos<Streams.size(); Pos++)
-        if (Streams[Pos].Parser)
-            Streams[Pos].Parser->Open_Buffer_Unsynch();
+        for (size_t Parser_Pos=0; Parser_Pos<Streams[Pos].Parsers.size(); Parser_Pos++)
+            Streams[Pos].Parsers[Parser_Pos]->Open_Buffer_Unsynch();
 
     #if MEDIAINFO_SEEK
         IFrame_IsParsed=false;
@@ -633,11 +698,11 @@ size_t File_Gxf::Read_Buffer_Seek (size_t Method, int64u Value, int64u)
                         }
                         else
                         {
-                            for (std::map<int8u, int64u>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); TimeCode++)
+                            for (std::map<int8u, tc>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); ++TimeCode)
                             {
-                                int64u TimeCode_First=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parser)->TimeCode_First;
+                                int64u TimeCode_First=((File_Gxf_TimeCode*)Streams[TimeCode->first].Parsers[0])->TimeCode_FirstFrame_ms;
                                 if (TimeCode_First==(int64u)-1)
-                                    TimeCode_First=TimeCode->second;
+                                    TimeCode_First=TimeCode->second.Milliseconds;
                                 if (TimeCode_First==(int64u)-1)
                                     Delay=0;
                                 else
@@ -697,11 +762,12 @@ bool File_Gxf::Header_Begin()
     #if MEDIAINFO_DEMUX
         //Handling of multiple frames in one block
         if (Element_Code==0xBF && Config->Demux_Unpacketize_Get()) //media block
-        {
-            Open_Buffer_Continue(Streams[TrackNumber].Parser, Buffer+Buffer_Offset, 0);
-            if (Config->Demux_EventWasSent)
-                return false;
-        }
+            for (size_t Pos=0; Pos<Streams[TrackNumber].Parsers.size(); Pos++)
+            {
+                Open_Buffer_Continue(Streams[TrackNumber].Parsers[Pos], Buffer+Buffer_Offset, 0);
+                if (Config->Demux_EventWasSent)
+                    return false;
+            }
     #endif //MEDIAINFO_DEMUX
 
     return true;
@@ -897,7 +963,7 @@ void File_Gxf::map()
                 TrackID&=0x3F; //Remove the 2 last bits
                 Streams[TrackID].MediaType=MediaType;
                 Streams[TrackID].TrackID=TrackID;
-                if (Streams[TrackID].Parser==NULL)
+                if (Streams[TrackID].Parsers.empty())
                 {
                     Streams[TrackID].MediaType=MediaType;
                     Streams[TrackID].TrackID=TrackID;
@@ -910,78 +976,106 @@ void File_Gxf::map()
                     {
                         case  3 :
                         case  4 :  //JPEG
-                                    Streams[TrackID].Parser=new File__Analyze; //Filling with following data
-                                    Open_Buffer_Init(Streams[TrackID].Parser);
-                                    Streams[TrackID].Parser->Accept();
-                                    Streams[TrackID].Parser->Fill();
-                                    Streams[TrackID].Parser->Stream_Prepare(Stream_Video);
-                                    Streams[TrackID].Parser->Fill(Stream_Video, 0, Video_Format, "JPEG");
+                                    {
+                                        File__Analyze* Parser=new File__Analyze;
+                                        Open_Buffer_Init(Parser);
+                                        Parser->Accept();
+                                        Parser->Fill();
+                                        Parser->Stream_Prepare(Stream_Video);
+                                        Parser->Fill(Stream_Video, 0, Video_Format, "JPEG");
+                                        Streams[TrackID].Parsers.push_back(Parser);
+                                    }
                                     break;
                         case  7 :
                         case  8 :
                         case 24 :  //TimeCode
-                                    Streams[TrackID].Parser=new File_Gxf_TimeCode;
-                                    Open_Buffer_Init(Streams[TrackID].Parser);
-                                    Parsers_Count++;
-                                    Streams[TrackID].Searching_Payload=true;
-                                    TimeCodes[TrackID]=(int64u)-1;
+                                    {
+                                        File__Analyze* Parser=new File_Gxf_TimeCode;
+                                        Open_Buffer_Init(Parser);
+                                        Streams[TrackID].Parsers.push_back(Parser);
+
+                                        Parsers_Count++;
+                                        Streams[TrackID].Searching_Payload=true;
+                                        TimeCodes[TrackID].Milliseconds=(int64u)-1;
+                                    }
                                     break;
                         case  9 :
                         case 10 :
-                                    Streams[TrackID].Parser=new File__Analyze; //Filling with following data
-                                    Open_Buffer_Init(Streams[TrackID].Parser);
-                                    Streams[TrackID].Parser->Accept();
-                                    Streams[TrackID].Parser->Fill();
-                                    Streams[TrackID].Parser->Stream_Prepare(Stream_Audio);
-                                    Streams[TrackID].Parser->Fill(Stream_Audio, 0, Audio_Format, "PCM");
-                                    Streams[TrackID].Parser->Fill(Stream_Audio, 0, Audio_Format_Settings_Endianness, "Little");
-                                    Audio_Count++;
+                                    {
+                                        File__Analyze* Parser=new File__Analyze;
+                                        Open_Buffer_Init(Parser);
+                                        Parser->Accept();
+                                        Parser->Fill();
+                                        Parser->Stream_Prepare(Stream_Audio);
+                                        Parser->Fill(Stream_Audio, 0, Audio_Format, "PCM");
+                                        Parser->Fill(Stream_Audio, 0, Audio_Format_Settings_Endianness, "Little");
+                                        Streams[TrackID].Parsers.push_back(Parser);
+
+                                        Audio_Count++;
+                                    }
                                     break;
                         case 11 :
                         case 12 :
                         case 20 :
                         case 22 :
                         case 23 :   //MPEG Video
-                                    Streams[TrackID].Parser=new File_Mpegv();
-                                    ((File_Mpegv*)Streams[TrackID].Parser)->FrameIsAlwaysComplete=true;
-                                    ((File_Mpegv*)Streams[TrackID].Parser)->Ancillary=&Ancillary;
-                                    Open_Buffer_Init(Streams[TrackID].Parser);
-                                    Parsers_Count++;
-                                    Streams[TrackID].Searching_Payload=true;
+                                     {
+                                        File__Analyze* Parser=new File_Mpegv();
+                                        ((File_Mpegv*)Parser)->FrameIsAlwaysComplete=true;
+                                        ((File_Mpegv*)Parser)->Ancillary=&Ancillary;
+                                        Open_Buffer_Init(Parser);
+                                        Streams[TrackID].Parsers.push_back(Parser);
+
+                                        Parsers_Count++;
+                                        Streams[TrackID].Searching_Payload=true;
+                                     }
                                     break;
                         case 13 :
                         case 14 :
                         case 15 :
                         case 16 :   //DV
-                                    Streams[TrackID].Parser=new File_DvDif();
-                                    Open_Buffer_Init(Streams[TrackID].Parser);
-                                    Parsers_Count++;
-                                    Streams[TrackID].Searching_Payload=true;
-                                    break;
-                        case 17 :   //AC-3 in AES3 (half)
-                        case 18 :   //Dolby E in AES3 (half)
-                                    Streams[TrackID].Parser=ChooseParser_ChannelGrouping(TrackID);
-                                    if (Streams[TrackID].Parser)
                                     {
-                                        Open_Buffer_Init(Streams[TrackID].Parser);
+                                        File__Analyze* Parser=new File_DvDif();
+                                        Open_Buffer_Init(Parser);
+                                        Streams[TrackID].Parsers.push_back(Parser);
+
                                         Parsers_Count++;
                                         Streams[TrackID].Searching_Payload=true;
                                     }
-                                    Audio_Count++;
+                                    break;
+                        case 17 :   //AC-3 in AES3 (half)
+                        case 18 :   //Dolby E in AES3 (half)
+                                    {
+                                        File__Analyze* Parser=ChooseParser_ChannelGrouping(TrackID);
+                                        if (Parser)
+                                        {
+                                            Open_Buffer_Init(Parser);
+                                            Streams[TrackID].Parsers.push_back(Parser);
+
+                                            Parsers_Count++;
+                                            Audio_Count++;
+                                            Streams[TrackID].Searching_Payload=true;
+                                        }
+                                    }
                                     break;
                         case 21 :   //Ancillary Metadata
-                                    Streams[TrackID].Parser=new File_Riff();
-                                    ((File_Riff*)Streams[TrackID].Parser)->Ancillary=&Ancillary;
-                                    Open_Buffer_Init(Streams[TrackID].Parser);
-                                    Parsers_Count++;
-                                    Streams[TrackID].Searching_Payload=true;
-                                    Ancillary=new File_Ancillary;
-                                    Ancillary->WithTenBit=true;
-                                    Ancillary->WithChecksum=true;
-                                    Open_Buffer_Init(Ancillary);
-                                    AncillaryData_StreamID=TrackID;
-                                    if (SizeToAnalyze<8*16*1024*1024)
-                                        SizeToAnalyze*=8; //10x more, to be sure to find captions
+                                    {
+                                        File__Analyze* Parser=new File_Riff();
+                                        ((File_Riff*)Parser)->Ancillary=&Ancillary;
+                                        Open_Buffer_Init(Parser);
+                                        Streams[TrackID].Parsers.push_back(Parser);
+
+                                        Parsers_Count++;
+                                        Streams[TrackID].Searching_Payload=true;
+
+                                        Ancillary=new File_Ancillary;
+                                        Ancillary->WithTenBit=true;
+                                        Ancillary->WithChecksum=true;
+                                        Open_Buffer_Init(Ancillary);
+                                        AncillaryData_StreamID=TrackID;
+                                        if (SizeToAnalyze<8*16*1024*1024)
+                                            SizeToAnalyze*=8; //10x more, to be sure to find captions
+                                    }
                                     break;
                         default :   ;
                     }
@@ -1114,9 +1208,10 @@ void File_Gxf::map()
                                 if (DataLength==4)
                                 {
                                     Get_B4 (Streams[TrackID].FrameRate_Code, "Content"); Param_Info1(Gxf_FrameRate(Streams[TrackID].FrameRate_Code)); Element_Info1(Gxf_FrameRate(Streams[TrackID].FrameRate_Code));
-                                    for (std::map<int8u, int64u>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); TimeCode++)
+                                    for (std::map<int8u, tc>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); ++TimeCode)
                                         if (TrackID==TimeCode->first)
-                                            ((File_Gxf_TimeCode*)Streams[TrackID].Parser)->FrameRate_Code=Streams[0x00].FrameRate_Code;
+                                            for (size_t Pos=0; Pos<Streams[TrackID].Parsers.size(); Pos++)
+                                                ((File_Gxf_TimeCode*)Streams[TrackID].Parsers[Pos])->FrameRate_Code=Streams[0x00].FrameRate_Code;
                                     if (Gxf_MediaTypes_StreamKind(MediaType)==Stream_Video)
                                         Stream_Video_FrameRate_Code=Streams[TrackID].FrameRate_Code;
                                 }
@@ -1140,9 +1235,10 @@ void File_Gxf::map()
                                         Stream_Video_FieldsPerFrame_Code=Streams[TrackID].FieldsPerFrame_Code;
                                         Material_Fields_FieldsPerFrame=Streams[TrackID].FieldsPerFrame_Code;
                                     }
-                                    for (std::map<int8u, int64u>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); TimeCode++)
+                                    for (std::map<int8u, tc>::iterator TimeCode=TimeCodes.begin(); TimeCode!=TimeCodes.end(); ++TimeCode)
                                         if (TrackID==TimeCode->first)
-                                            ((File_Gxf_TimeCode*)Streams[TrackID].Parser)->FieldsPerFrame_Code=Streams[0x00].FieldsPerFrame_Code;
+                                            for (size_t Pos=0; Pos<Streams[TrackID].Parsers.size(); Pos++)
+                                                ((File_Gxf_TimeCode*)Streams[TrackID].Parsers[Pos])->FieldsPerFrame_Code=Streams[0x00].FieldsPerFrame_Code;
                                 }
                                 else
                                     Skip_XX(DataLength,         "Unknown");
@@ -1156,13 +1252,21 @@ void File_Gxf::map()
             //Test on TimeCode
             if (TimeCode_Parsed && !Invalid)
             {
-                std::map<int8u, int64u>::iterator TimeCode=TimeCodes.find(TrackID);
-                if (TimeCode==TimeCodes.end() || TimeCode->second==(int64u)-1)
+                std::map<int8u, tc>::iterator TimeCode=TimeCodes.find(TrackID);
+                if (TimeCode==TimeCodes.end() || TimeCode->second.Milliseconds==(int64u)-1)
                 {
                     float64 FrameRate=Gxf_FrameRate(Streams[TrackID].FrameRate_Code);
-                    TimeCodes[TrackID]=Hours  *60*60*1000
-                                      +Minutes   *60*1000
-                                      +Seconds      *1000;
+                    TimeCodes[TrackID].Milliseconds=Hours  *60*60*1000
+                                                   +Minutes   *60*1000
+                                                   +Seconds      *1000;
+                    MediaInfoLib::TimeCode TC;
+                    TC.Hours=Hours;
+                    TC.Minutes=Minutes;
+                    TC.Seconds=Seconds;
+                    TC.Frames=Fields/2;
+                    TC.DropFrame=DropFrame;
+                    TimeCodes[TrackID].String=TC.ToString();
+
                     if (!FrameRate)
                     {
                         //Time code frame rate is missing, using the video frame rate
@@ -1260,9 +1364,9 @@ void File_Gxf::media()
                 int64u TimeCode_First=0;
                 if (!TimeCodes.empty())
                 {
-                    TimeCode_First=((File_Gxf_TimeCode*)Streams[TimeCodes.begin()->first].Parser)->TimeCode_First;
+                    TimeCode_First=((File_Gxf_TimeCode*)Streams[TimeCodes.begin()->first].Parsers[0])->TimeCode_FirstFrame_ms;
                     if (TimeCode_First==(int64u)-1)
-                        TimeCode_First=TimeCodes.begin()->second;
+                        TimeCode_First=TimeCodes.begin()->second.Milliseconds;
                 }
                 if (TimeCode_First!=(int64u)-1)
                     TimeCode_First*=1000000;
@@ -1319,7 +1423,7 @@ void File_Gxf::media()
                 {
                     if (Gxf_MediaTypes_StreamKind(Streams[TrackNumber].MediaType)!=Stream_Audio)
                         Frame_Count_NotParsedIncluded=(MediaFieldNumber-(Material_Fields_First_IsValid?Material_Fields_First:0))/Material_Fields_FieldsPerFrame;
-                    Demux_Level=(Streams[TrackNumber].Parser && (Streams[TrackNumber].Parser->Demux_UnpacketizeContainer || Streams[TrackNumber].Parser->Demux_Level==2))?4:2; //Intermediate (D-10 Audio) / Container
+                    Demux_Level=(!Streams[TrackNumber].Parsers.empty() && (Streams[TrackNumber].Parsers[0]->Demux_UnpacketizeContainer || Streams[TrackNumber].Parsers[0]->Demux_Level==2))?4:2; //Intermediate (D-10 Audio) / Container
                     Demux(Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset), ContentType_MainStream);
                 }
                 Element_Code=0xBF; //media
@@ -1334,20 +1438,45 @@ void File_Gxf::media()
         return;
     }
 
-    if (Streams[TrackNumber].Parser)
+    for (size_t Pos=0; Pos<Streams[TrackNumber].Parsers.size(); Pos++)
     {
-        Streams[TrackNumber].Parser->FrameInfo.DTS=FrameInfo.DTS;
-        Open_Buffer_Continue(Streams[TrackNumber].Parser, Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset));
-        if (MediaInfoLib::Config.ParseSpeed_Get()<1 && Streams[TrackNumber].Parser->Status[IsFilled])
-        {
-            Streams[TrackNumber].Searching_Payload=false;
+        Streams[TrackNumber].Parsers[Pos]->FrameInfo.DTS=FrameInfo.DTS;
+        Open_Buffer_Continue(Streams[TrackNumber].Parsers[Pos], Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset));
 
-            if (Parsers_Count>0)
-                Parsers_Count--;
-            if (Parsers_Count==0)
+        //Multiple parsers
+        if (Streams[TrackNumber].Parsers.size()>1)
+        {
+            if (!Streams[TrackNumber].Parsers[Pos]->Status[IsAccepted] && Streams[TrackNumber].Parsers[Pos]->Status[IsFinished])
             {
-                Finish();
+                delete *(Streams[TrackNumber].Parsers.begin()+Pos);
+                Streams[TrackNumber].Parsers.erase(Streams[TrackNumber].Parsers.begin()+Pos);
+                Pos--;
             }
+            else if (Streams[TrackNumber].Parsers.size()>1 && Streams[TrackNumber].Parsers[Pos]->Status[IsAccepted])
+            {
+                File__Analyze* Parser=Streams[TrackNumber].Parsers[Pos];
+                for (size_t Pos2=0; Pos2<Streams[TrackNumber].Parsers.size(); Pos2++)
+                {
+                    if (Pos2!=Pos)
+                        delete *(Streams[TrackNumber].Parsers.begin()+Pos2);
+                }
+                Streams[TrackNumber].Parsers.clear();
+                Streams[TrackNumber].Parsers.push_back(Parser);
+            }
+        }
+    }
+
+    Element_Offset=Element_Size;
+
+    if (MediaInfoLib::Config.ParseSpeed_Get()<1 && Streams[TrackNumber].Parsers.size()==1 && Streams[TrackNumber].Parsers[0]->Status[IsFilled])
+    {
+        Streams[TrackNumber].Searching_Payload=false;
+
+        if (Parsers_Count>0)
+            Parsers_Count--;
+        if (Parsers_Count==0)
+        {
+            Finish();
         }
     }
 }
@@ -1445,23 +1574,25 @@ File__Analyze* File_Gxf::ChooseParser_ChannelGrouping(int8u TrackID)
             return NULL; //Not a channel grouping
 
         Parser=new File_ChannelGrouping;
+        Parser->CanBePcm=true;;
         Parser->Channel_Pos=1;
-        Parser->Common=((File_ChannelGrouping*)Streams[TrackID-1].Parser)->Common;
+        Parser->Common=((File_ChannelGrouping*)Streams[TrackID-1].Parsers[0])->Common;
         Parser->StreamID=TrackID-1;
-        Streams[TrackID].DisplayInfo=false;
+        Streams[TrackID].IsChannelGrouping=true;
     }
     else
     {
         Parser=new File_ChannelGrouping;
+        Parser->CanBePcm=true;;
         Parser->Channel_Pos=0;
         //if (Descriptor->second.Infos.find("SamplingRate")!=Descriptor->second.Infos.end())
-        Parser->SampleRate=48000; //TODO: find where this piece of info is avaialble
         Streams[TrackID].IsChannelGrouping=true;
+        Streams[TrackID].DisplayInfo=false;
     }
+    Parser->BitDepth=24;
     Parser->Channel_Total=2;
+    Parser->SamplingRate=48000; //TODO: find where this piece of info is avaialble
     Parser->Endianness='L';
-    Parser->ByteDepth=3;
-    Parser->IsAes3=true;
 
     #if MEDIAINFO_DEMUX
         if (Demux_UnpacketizeContainer)
