@@ -1,20 +1,9 @@
-// File_Mpeg - Info for MPEG files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about MPEG files
@@ -29,7 +18,6 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/File__Analyze.h"
 #include "MediaInfo/Multiple/File_Mpeg4_Descriptors.h"
-#include <map>
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -209,6 +197,8 @@ private :
         Mpeg_TimeStamp TimeStamp_Start;
         Mpeg_TimeStamp TimeStamp_End;
         size_t         StreamIsRegistred;
+        size_t         StreamOrder;
+        size_t         FirstPacketOrder;
         bool           Searching_Payload;
         bool           Searching_TimeStamp_Start;
         bool           Searching_TimeStamp_End;
@@ -224,6 +214,8 @@ private :
             descriptor_tag=0x00; //No info
             DVD_Identifier=0;
             StreamIsRegistred=0;
+            StreamOrder=(size_t)-1;
+            FirstPacketOrder=(size_t)-1;
             Searching_Payload=false;
             Searching_TimeStamp_Start=false;
             Searching_TimeStamp_End=false;
@@ -247,6 +239,9 @@ private :
     bool   video_stream_Unlimited;
     int16u Buffer_DataSizeToParse;
     std::vector<int64u> video_stream_PTS;
+    size_t StreamOrder_CountOfPrivateStreams_Minus1;
+    size_t StreamOrder_CountOfPrivateStreams_Temp;
+    size_t FirstPacketOrder_Last;
 
     //Helpers
     bool Header_Parser_QuickSearch();
@@ -255,6 +250,7 @@ private :
     File__Analyze* ChooseParser_Mpegv();
     File__Analyze* ChooseParser_Mpeg4v();
     File__Analyze* ChooseParser_Avc();
+    File__Analyze* ChooseParser_Hevc();
     File__Analyze* ChooseParser_VC1();
     File__Analyze* ChooseParser_Dirac();
     File__Analyze* ChooseParser_Mpega();
@@ -265,8 +261,9 @@ private :
     File__Analyze* ChooseParser_SDDS();
     File__Analyze* ChooseParser_AAC();
     File__Analyze* ChooseParser_PCM();
-    File__Analyze* ChooseParser_AES3();
+    File__Analyze* ChooseParser_SmpteSt0302();
     File__Analyze* ChooseParser_RLE();
+    File__Analyze* ChooseParser_AribStdB24B37(bool HasCcis=false);
     File__Analyze* ChooseParser_DvbSubtitle();
     File__Analyze* ChooseParser_PGS();
     File__Analyze* ChooseParser_Teletext();
@@ -295,9 +292,6 @@ private :
         int64u                      Seek_ID;
         bool                        Duration_Detected;
     #endif //MEDIAINFO_SEEK
-    #if MEDIAINFO_SEEK && MEDIAINFO_IBI
-        ibi Ibi;
-    #endif //MEDIAINFO_SEEK && MEDIAINFO_IBI
 };
 
 } //NameSpace
