@@ -1,20 +1,9 @@
-// File_Mpegts - Info for MPEG Transport Stream files
-// Copyright (C) 2006-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about MPEG Transport Stream files
@@ -30,9 +19,6 @@
 #include "MediaInfo/File__Duplicate.h"
 #include "MediaInfo/Multiple/File_Mpeg_Psi.h"
 #include "MediaInfo/Duplicate/File__Duplicate_MpegTs.h"
-#include "MediaInfo/Duplicate/File__Duplicate__Writer.h"
-#include <map>
-#include <vector>
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -134,6 +120,11 @@ private :
     void Streams_Update_EPG_PerProgram(complete_stream::transport_stream::programs::iterator Program);
     #ifdef MEDIAINFO_MPEGTS_PCR_YES
     void Streams_Update_Duration_Update();
+    #if MEDIAINFO_ADVANCED
+        float64 Config_VbrDetection_Delta;
+        int64u  Config_VbrDetection_Occurences;
+        bool    Config_VbrDetection_GiveUp;
+    #endif // MEDIAINFO_ADVANCED
     #endif //MEDIAINFO_MPEGTS_PCR_YES
     void Streams_Update_Duration_End();
 
@@ -161,9 +152,6 @@ private :
         size_t                      InfiniteLoop_Detect;
         bool                        Duration_Detected;
     #endif //MEDIAINFO_SEEK
-    #if MEDIAINFO_SEEK && MEDIAINFO_IBI
-        ibi Ibi;
-    #endif //MEDIAINFO_SEEK && MEDIAINFO_IBI
 };
 
 } //NameSpace
