@@ -1,20 +1,9 @@
-// File_Wm - Info for Windows Media files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Main part
@@ -109,7 +98,7 @@ void File_Wm::Streams_Finish()
     std::map<int16u, stream>::iterator Temp=Stream.begin();
     while (Temp!=Stream.end())
     {
-        for (std::map<std::string, ZenLib::Ztring>::iterator Info_Temp=Temp->second.Info.begin(); Info_Temp!=Temp->second.Info.end(); Info_Temp++)
+        for (std::map<std::string, ZenLib::Ztring>::iterator Info_Temp=Temp->second.Info.begin(); Info_Temp!=Temp->second.Info.end(); ++Info_Temp)
             Fill(Temp->second.StreamKind, Temp->second.StreamPos, Info_Temp->first.c_str(), Info_Temp->second, true);
 
         //Codec Info
@@ -128,7 +117,7 @@ void File_Wm::Streams_Finish()
             //Some tests about the frame rate
             std::map<int32u, int32u> PresentationTime_Deltas_Problem;
             std::map<int32u, int32u> PresentationTime_Deltas_Most;
-            for (std::map<ZenLib::int32u, ZenLib::int32u>::iterator PresentationTime_Delta=Temp->second.PresentationTime_Deltas.begin(); PresentationTime_Delta!=Temp->second.PresentationTime_Deltas.end(); PresentationTime_Delta++)
+            for (std::map<ZenLib::int32u, ZenLib::int32u>::iterator PresentationTime_Delta=Temp->second.PresentationTime_Deltas.begin(); PresentationTime_Delta!=Temp->second.PresentationTime_Deltas.end(); ++PresentationTime_Delta)
             {
                 if (PresentationTime_Delta->second>=5)
                     PresentationTime_Deltas_Problem[PresentationTime_Delta->first]=PresentationTime_Delta->second;
@@ -136,7 +125,7 @@ void File_Wm::Streams_Finish()
                     PresentationTime_Deltas_Most[PresentationTime_Delta->first]=PresentationTime_Delta->second;
             }
 
-            if (PresentationTime_Deltas_Most.size()==0
+            if (PresentationTime_Deltas_Most.empty()
              || (PresentationTime_Deltas_Most.size()==1 && PresentationTime_Deltas_Problem.size()>1)
              || (PresentationTime_Deltas_Most.size()==2 && PresentationTime_Deltas_Problem.size()>2))
             {
@@ -155,7 +144,7 @@ void File_Wm::Streams_Finish()
                 std::map<int32u, int32u>::iterator PresentationTime_Delta_Most=PresentationTime_Deltas_Most.begin();
                 float64 PresentationTime_Deltas_1_Value=(float64)PresentationTime_Delta_Most->first;
                 float64 PresentationTime_Deltas_1_Count=(float64)PresentationTime_Delta_Most->second;
-                PresentationTime_Delta_Most++;
+                ++PresentationTime_Delta_Most;
                 float64 PresentationTime_Deltas_2_Value=(float64)PresentationTime_Delta_Most->first;
                 float64 PresentationTime_Deltas_2_Count=(float64)PresentationTime_Delta_Most->second;
                 float64 FrameRate_Real=1000/(((PresentationTime_Deltas_1_Value*PresentationTime_Deltas_1_Count)+(PresentationTime_Deltas_2_Value*PresentationTime_Deltas_2_Count))/(PresentationTime_Deltas_1_Count+PresentationTime_Deltas_2_Count));
@@ -211,7 +200,7 @@ void File_Wm::Streams_Finish()
                 Fill(Stream_Video, Temp->second.StreamPos, Video_Format_Profile, Format_Profile, true);
         }
 
-        Temp++;
+        ++Temp;
     }
 
     if (Count_Get(Stream_Video)==0 && Count_Get(Stream_Image)==0)
