@@ -1,20 +1,9 @@
-// File_Wm - Info for Windows Media files
-// Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Elements part
@@ -145,7 +134,7 @@ namespace Elements
     UUID(Mutex_Bitrate,                                         D6E22A01, 35DA, 11D1, 9034, 00A0C90349BE);
 }
 
-const char* Wm_StreamType(int128u Kind)
+const char* Wm_StreamType(const int128u Kind)
 {
     switch (Kind.hi)
     {
@@ -160,7 +149,7 @@ const char* Wm_StreamType(int128u Kind)
     }
 }
 
-const char* Wm_ExclusionType(int128u ExclusionType)
+const char* Wm_ExclusionType(const int128u ExclusionType)
 {
     switch (ExclusionType.hi)
     {
@@ -243,6 +232,7 @@ void File_Wm::Header()
 
     FILLING_BEGIN();
         Fill(Stream_General, 0, General_Format, "Windows Media");
+        Header_StreamProperties_StreamOrder=0;
     FILLING_END();
 }
 
@@ -333,6 +323,8 @@ void File_Wm::Header_StreamProperties ()
     Stream[Stream_Number].StreamKind=StreamKind_Last;
     Stream[Stream_Number].StreamPos=StreamPos_Last;
     Stream[Stream_Number].Info["ID"].From_Number(Stream_Number);
+    Stream[Stream_Number].Info["StreamOrder"].From_Number(Header_StreamProperties_StreamOrder);
+    Header_StreamProperties_StreamOrder++;
 }
 
 //---------------------------------------------------------------------------
@@ -400,6 +392,25 @@ void File_Wm::Header_StreamProperties_Audio_WMA ()
 {
     Element_Info1("WMA");
 
+            //Demux
+            #if MEDIAINFO_DEMUX
+                switch (Config->Demux_InitData_Get())
+                {
+                    case 0 :    //In demux event
+                                Demux_Level=2; //Container
+                                Demux(Buffer+Buffer_Offset, (size_t)Element_Size, ContentType_Header);
+                                break;
+                    case 1 :    //In field
+                                {
+                                std::string Data_Raw((const char*)(Buffer+Buffer_Offset+Element_Offset), (size_t)10);//Element_Size-(Element_Offset));
+                                std::string Data_Base64(Base64::encode(Data_Raw));
+                                Fill(Stream_Audio, StreamPos_Last, "Demux_InitBytes", Data_Base64);
+                                }
+                                break;
+                    default :   ;
+                }
+            #endif //MEDIAINFO_DEMUX
+
     //Parsing
     Skip_L4(                                                    "SamplesPerBlock");
     Skip_L2(                                                    "EncodeOptions");
@@ -1342,7 +1353,7 @@ void File_Wm::Data()
             Temp->second.SearchingPayload=true;
             Streams_Count++;
         }
-        Temp++;
+        ++Temp;
     }
 
     //Enabling the alternative parser
@@ -1518,21 +1529,29 @@ void File_Wm::Data_Packet()
             return; //problem
         }
 
+        //Demux
+        Element_Code=Stream_Number;
+        Demux(Buffer+(size_t)Element_Offset, (size_t)PayloadLength, ContentType_MainStream);
+
         //Analyzing
         if (Stream[Stream_Number].Parser && Stream[Stream_Number].SearchingPayload)
         {
             //Handling of spanned on multiple chunks
-            bool FrameIsAlwaysComplete=true;
+            #if defined(MEDIAINFO_VC1_YES)
+                bool FrameIsAlwaysComplete=true;
+            #endif
             if (PayloadLength!=SizeOfMediaObject)
             {
                 if (SizeOfMediaObject_BytesAlreadyParsed==0)
                     SizeOfMediaObject_BytesAlreadyParsed=SizeOfMediaObject-PayloadLength;
                 else
                     SizeOfMediaObject_BytesAlreadyParsed-=PayloadLength;
-                if (SizeOfMediaObject_BytesAlreadyParsed!=0)
-                    FrameIsAlwaysComplete=false;
-                else
+                if (SizeOfMediaObject_BytesAlreadyParsed==0)
                     Element_Show_Count++;
+                #if defined(MEDIAINFO_VC1_YES)
+                else
+                    FrameIsAlwaysComplete=false;
+                #endif
             }
             else
                 Element_Show_Count++;
@@ -1543,9 +1562,6 @@ void File_Wm::Data_Packet()
                 ((File_Vc1*)Stream[Stream_Number].Parser)->FrameIsAlwaysComplete=FrameIsAlwaysComplete;
             #endif
 
-            Element_Code=Stream_Number;
-            Demux(Buffer+(size_t)Element_Offset, (size_t)PayloadLength, ContentType_MainStream);
-
             Open_Buffer_Continue(Stream[Stream_Number].Parser, (size_t)PayloadLength);
             if (Stream[Stream_Number].Parser->Status[IsFinished]
              || (Stream[Stream_Number].PresentationTime_Count>=300 && MediaInfoLib::Config.ParseSpeed_Get()<1))
