@@ -1,21 +1,8 @@
-// File__ReferenceFilesHelper - class for analyzing/demuxing reference files
-// Copyright (C) 2011-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -42,6 +29,9 @@
 #include "ZenLib/Format/Http/Http_Utils.h"
 #include <set>
 #include <algorithm>
+#if MEDIAINFO_EVENTS
+    #include "MediaInfo/MediaInfo_Events_Internal.h"
+#endif //MEDIAINFO_EVENTS
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -60,11 +50,24 @@ File__ReferenceFilesHelper::File__ReferenceFilesHelper(File__Analyze* MI_, Media
     Reference=References.end();
     Init_Done=false;
     TestContinuousFileNames=false;
+    ContainerHasNoId=false;
+    HasMainFile=false;
+    ID_Max=0;
     FrameRate=0;
     Duration=0;
     #if MEDIAINFO_NEXTPACKET
         DTS_Interval=(int64u)-1;
     #endif //MEDIAINFO_NEXTPACKET
+    #if MEDIAINFO_EVENTS
+        StreamID_Previous=(int64u)-1;
+    #endif //MEDIAINFO_EVENTS
+}
+
+//---------------------------------------------------------------------------
+File__ReferenceFilesHelper::~File__ReferenceFilesHelper()
+{
+    for (references::iterator ReferenceTemp=References.begin(); ReferenceTemp!=References.end(); ++ReferenceTemp)
+        delete ReferenceTemp->MI; //ReferenceTemp->MI=NULL;
 }
 
 //***************************************************************************
@@ -79,13 +82,23 @@ void File__ReferenceFilesHelper::ParseReferences()
 {
     if (!Init_Done)
     {
+        #if MEDIAINFO_FILTER
+            if (MI->Config->File_Filter_Audio_Get())
+                for (size_t Pos=0; Pos<References.size(); Pos++)
+                    if (References[Pos].StreamKind!=Stream_Audio)
+                    {
+                        References.erase(References.begin()+Pos);
+                        Pos--;
+                    }
+        #endif //MEDIAINFO_FILTER
+
         //Testing IDs
         std::sort(References.begin(), References.end(), File__ReferenceFilesHelper_Algo1);
         std::sort(References.begin(), References.end(), File__ReferenceFilesHelper_Algo2);
         std::sort(References.begin(), References.end(), File__ReferenceFilesHelper_Algo3);
         std::set<int64u> StreamList;
         bool StreamList_DuplicatedIds=false;
-        for (Reference=References.begin(); Reference<References.end(); Reference++)
+        for (Reference=References.begin(); Reference<References.end(); ++Reference)
             if (StreamList.find((*Reference).StreamID)==StreamList.end())
                 StreamList.insert((*Reference).StreamID);
             else
@@ -94,7 +107,7 @@ void File__ReferenceFilesHelper::ParseReferences()
                 break;
             }
         if (StreamList_DuplicatedIds)
-            for (Reference=References.begin(); Reference<References.end(); Reference++)
+            for (Reference=References.begin(); Reference<References.end(); ++Reference)
                 (*Reference).StreamID=Reference-References.begin()+1;
 
         //Configuring file names
@@ -248,26 +261,28 @@ void File__ReferenceFilesHelper::ParseReferences()
                 MI->Fill(Reference->StreamKind, Reference->StreamPos, "Source_Info", "Missing");
             }
 
-            if (TestContinuousFileNames)
-                File__Analyze::Streams_Accept_TestContinuousFileNames_Static(Reference->FileNames, true);
-
-            Reference++;
+            ++Reference;
         }
 
-        #if MEDIAINFO_DEMUX
+        #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
             if (Config->NextPacket_Get())
             {
                 Demux_Interleave=Config->File_Demux_Interleave_Get();
                 if (Demux_Interleave)
                 {
                     CountOfReferencesToParse=References.size();
+                    for (references::iterator ReferenceSource=References.begin(); ReferenceSource!=References.end(); ++ReferenceSource)
+                        if (ReferenceSource->FileNames.empty())
+                            CountOfReferencesToParse--;
                     DTS_Interval=3000000000; // 3 seconds
                 }
             }
+            else
+                Demux_Interleave=false;
 
             //Using the frame rate from the first stream having a frame rate
             if (!FrameRate)
-                for (references::iterator ReferenceFrameRate=References.begin(); ReferenceFrameRate!=References.end(); ReferenceFrameRate++)
+                for (references::iterator ReferenceFrameRate=References.begin(); ReferenceFrameRate!=References.end(); ++ReferenceFrameRate)
                     if (ReferenceFrameRate->FrameRate)
                     {
                         FrameRate=ReferenceFrameRate->FrameRate;
@@ -301,31 +316,19 @@ void File__ReferenceFilesHelper::ParseReferences()
                 }
 
             }
-        #endif //MEDIAINFO_DEMUX
+        #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
 
         FileSize_Compute();
         Reference=References.begin();
         Init_Done=true;
-        /*
-        #if MEDIAINFO_EVENTS
-            struct MediaInfo_Event_General_SubFile_Start_0 Event;
-            MI->Event_Prepare((struct MediaInfo_Event_Generic*)&Event);
-            Event.EventCode=MediaInfo_EventCode_Create(0, MediaInfo_Event_General_SubFile_Start, 0);
-            Event.EventSize=sizeof(struct MediaInfo_Event_General_SubFile_Start_0);
 
-            Event.FileName_Relative_Unicode=Reference->Source.c_str();
-
-            MI->Config->Event_Send(NULL, (const int8u*)&Event, Event.EventSize, MI->File_Name);
-        #endif //MEDIAINFO_EVENTS
-        */
-
-        #if MEDIAINFO_DEMUX
+        #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
             if (Config->NextPacket_Get() && MI->Demux_EventWasSent_Accept_Specific)
             {
                 MI->Config->Demux_EventWasSent=true;
                 return;
             }
-        #endif //MEDIAINFO_DEMUX
+        #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
     }
 
     while (Reference!=References.end())
@@ -340,7 +343,7 @@ void File__ReferenceFilesHelper::ParseReferences()
         #if MEDIAINFO_NEXTPACKET
             DTS_Minimal=(int64u)-1;
         #endif //MEDIAINFO_NEXTPACKET
-        for (references::iterator ReferenceTemp=References.begin(); ReferenceTemp!=References.end(); ReferenceTemp++)
+        for (references::iterator ReferenceTemp=References.begin(); ReferenceTemp!=References.end(); ++ReferenceTemp)
         {
             if (ReferenceTemp->MI)
             {
@@ -363,42 +366,25 @@ void File__ReferenceFilesHelper::ParseReferences()
         }
         Config->State_Set(((float)FileSize_Parsed)/MI->Config->File_Size);
 
-        /*
         #if MEDIAINFO_EVENTS
             struct MediaInfo_Event_General_SubFile_End_0 Event;
             MI->Event_Prepare((struct MediaInfo_Event_Generic*)&Event);
             Event.EventCode=MediaInfo_EventCode_Create(0, MediaInfo_Event_General_SubFile_End, 0);
             Event.EventSize=sizeof(struct MediaInfo_Event_General_SubFile_End_0);
 
-            Event.FileName_Relative_Unicode=Reference->Source.c_str();
-
             MI->Config->Event_Send(NULL, (const int8u*)&Event, Event.EventSize, MI->File_Name);
         #endif //MEDIAINFO_EVENTS
-        */
 
-        #if MEDIAINFO_DEMUX
+        #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
             if (Demux_Interleave)
             {
-                references::iterator Reference_Next=Reference; Reference_Next++;
+                references::iterator Reference_Next=Reference; ++Reference_Next;
 
                 if (Reference_Next==References.end() && Config->NextPacket_Get() && CountOfReferencesToParse)
                     Reference=References.begin();
                 else
                     Reference=Reference_Next;
 
-                /*
-                #if MEDIAINFO_EVENTS
-                    struct MediaInfo_Event_General_SubFile_Start_0 Event;
-                    MI->Event_Prepare((struct MediaInfo_Event_Generic*)&Event);
-                    Event.EventCode=MediaInfo_EventCode_Create(0, MediaInfo_Event_General_SubFile_Start, 0);
-                    Event.EventSize=sizeof(struct MediaInfo_Event_General_SubFile_Start_0);
-
-                    Event.FileName_Relative_Unicode=Reference->Source.c_str();
-
-                    MI->Config->Event_Send(NULL, (const int8u*)&Event, Event.EventSize, MI->File_Name);
-                #endif //MEDIAINFO_EVENTS
-                */
-
                 if (Config->Demux_EventWasSent)
                     return;
             }
@@ -409,30 +395,18 @@ void File__ReferenceFilesHelper::ParseReferences()
 
                 Reference++;
             }
-        #else //MEDIAINFO_DEMUX
-            Reference++;
+        #else //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
+            ++Reference;
         #endif //MEDIAINFO_DEMUX
-
-        /*
-        #if MEDIAINFO_EVENTS
-            if (Reference!=References.end())
-            {
-                struct MediaInfo_Event_General_SubFile_Start_0 Event;
-                MI->Event_Prepare((struct MediaInfo_Event_Generic*)&Event);
-                Event.EventCode=MediaInfo_EventCode_Create(0, MediaInfo_Event_General_SubFile_Start, 0);
-                Event.EventSize=sizeof(struct MediaInfo_Event_General_SubFile_Start_0);
-
-                Event.FileName_Relative_Unicode=Reference->Source.c_str();
-
-                MI->Config->Event_Send(NULL, (const int8u*)&Event, Event.EventSize, MI->File_Name);
-            }
-        #endif //MEDIAINFO_EVENTS
-        */
     }
 
     //File size handling
     FileSize_Compute();
-    if (MI->Config->File_Size!=MI->File_Size)
+    if (MI->Config->File_Size!=MI->File_Size
+        #if MEDIAINFO_ADVANCED
+            && !Config->File_IgnoreSequenceFileSize_Get()
+        #endif //MEDIAINFO_ADVANCED
+            )
     {
         MI->Fill(Stream_General, 0, General_FileSize, MI->Config->File_Size, 10, true);
         MI->Fill(Stream_General, 0, General_StreamSize, MI->File_Size, 10, true);
@@ -451,15 +425,28 @@ void File__ReferenceFilesHelper::ParseReference()
         Reference->MI->Option(__T("File_KeepInfo"), __T("1"));
         Reference->MI->Option(__T("File_ID_OnlyRoot"), Config->File_ID_OnlyRoot_Get()?__T("1"):__T("0"));
         Reference->MI->Option(__T("File_DvDif_DisableAudioIfIsInContainer"), Config->File_DvDif_DisableAudioIfIsInContainer_Get()?__T("1"):__T("0"));
-        if (References.size()>1 || Config->File_MpegTs_ForceMenu_Get())
+        if ((References.size()>1 || Config->File_MpegTs_ForceMenu_Get()) && !Reference->IsMain && !HasMainFile)
             Reference->MI->Option(__T("File_MpegTs_ForceMenu"), __T("1"));
         #if MEDIAINFO_NEXTPACKET
             if (Config->NextPacket_Get())
                 Reference->MI->Option(__T("File_NextPacket"), __T("1"));
         #endif //MEDIAINFO_NEXTPACKET
+        #if MEDIAINFO_ADVANCED
+            if (Config->File_IgnoreSequenceFileSize_Get())
+                Reference->MI->Option(__T("File_IgnoreSequenceFileSize"), __T("1"));
+            if (Config->File_Source_List_Get())
+                Reference->MI->Option(__T("File_Source_List"), __T("1"));
+        #endif //MEDIAINFO_ADVANCED
+        #if MEDIAINFO_MD5
+            if (Config->File_Md5_Get())
+                Reference->MI->Option(__T("File_MD5"), __T("1"));
+        #endif //MEDIAINFO_MD5
         #if MEDIAINFO_EVENTS
             if (Config->Event_CallBackFunction_IsSet())
                 Reference->MI->Option(__T("File_Event_CallBackFunction"), Config->Event_CallBackFunction_Get());
+            Reference->MI->Config.File_Names_RootDirectory=FileName(MI->File_Name).Path_Get();
+            if (Reference->FileNames.size()>1)
+                Reference->MI->Option(__T("File_TestContinuousFileNames"), __T("0"));
             ZtringListList SubFile_IDs;
             for (size_t Pos=0; Pos<MI->StreamIDs_Size; Pos++)
             {
@@ -526,6 +513,9 @@ void File__ReferenceFilesHelper::ParseReference()
         else
         {
             //Run
+            #if MEDIAINFO_EVENTS
+                SubFile_Start();
+            #endif //MEDIAINFO_EVENTS
             if (!Reference->MI->Open(Reference->FileNames.Read()))
             {
                 MI->Fill(Reference->StreamKind, Reference->StreamPos, "Source_Info", "Missing");
@@ -558,6 +548,7 @@ void File__ReferenceFilesHelper::ParseReference()
             if (Config->Event_CallBackFunction_IsSet() && !Reference->Status[File__Analyze::IsFinished])
             {
                 #if MEDIAINFO_DEMUX
+                    SubFile_Start();
                     while ((Reference->Status=Reference->MI->Open_NextPacket())[8])
                     {
                             if (Config->Event_CallBackFunction_IsSet())
@@ -599,7 +590,7 @@ void File__ReferenceFilesHelper::ParseReference_Finalize ()
             else
             {
                 size_t ToInsert=(size_t)-1;
-                for (references::iterator ReferencePos=References.begin(); ReferencePos!=References.end(); ReferencePos++)
+                for (references::iterator ReferencePos=References.begin(); ReferencePos!=References.end(); ++ReferencePos)
                     if (ReferencePos->StreamKind==StreamKind_Last && Reference->StreamID<ReferencePos->StreamID)
                     {
                         ToInsert=ReferencePos->StreamPos;
@@ -628,13 +619,29 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
     //Hacks - Before
     Ztring CodecID=MI->Retrieve(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_CodecID));
     Ztring ID_Base;
-    if (Reference->StreamID!=(int64u)-1)
+    if (HasMainFile)
+        ID_Base=Ztring::ToZtring(ID_Max+Reference->StreamID-1);
+    else if (Reference->StreamID!=(int64u)-1)
         ID_Base=Ztring::ToZtring(Reference->StreamID);
     Ztring ID=ID_Base;
     Ztring ID_String=ID_Base;
     Ztring MenuID;
     Ztring MenuID_String;
 
+    if (!HasMainFile && Reference->IsMain)
+    {
+        MI->Fill(Stream_General, 0, General_Format, Reference->MI->Get(Stream_General, 0, General_Format) , true);
+        MI->Fill(Stream_General, 0, General_CompleteName, Reference->MI->Get(Stream_General, 0, General_CompleteName) , true);
+        MI->Fill(Stream_General, 0, General_FileExtension, Reference->MI->Get(Stream_General, 0, General_FileExtension) , true);
+        HasMainFile=true;
+    }
+    if (Reference->IsMain)
+    {
+        int64u ID_New=Reference->MI->Get(StreamKind_Last, StreamPos_From, General_ID).To_int64u();
+        if (ID_Max<ID_New)
+            ID_Max=ID_New;
+    }
+
     MI->Clear(StreamKind_Last, StreamPos_To, General_ID);
 
     MI->Merge(*Reference->MI->Info, StreamKind_Last, StreamPos_From, StreamPos_To);
@@ -644,14 +651,14 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
         MI->Fill(Stream_Video, StreamPos_To, Video_FrameRate, Reference->FrameRate, 3 , true);
 
     //Hacks - After
-    if (CodecID!=MI->Retrieve(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_CodecID)))
+    if (!Reference->IsMain && CodecID!=MI->Retrieve(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_CodecID)))
     {
         if (!CodecID.empty())
             CodecID+=__T(" / ");
         CodecID+=MI->Retrieve(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_CodecID));
         MI->Fill(StreamKind_Last, StreamPos_To, MI->Fill_Parameter(StreamKind_Last, Generic_CodecID), CodecID, true);
     }
-    if (Reference->MI->Count_Get(Stream_Video)+Reference->MI->Count_Get(Stream_Audio)>1 && Reference->MI->Get(Stream_Video, 0, Video_Format)!=__T("DV"))
+    if (!Reference->IsMain && Reference->MI->Count_Get(Stream_Video)+Reference->MI->Count_Get(Stream_Audio)>1 && Reference->MI->Get(Stream_Video, 0, Video_Format)!=__T("DV"))
     {
         if (StreamKind_Last==Stream_Menu)
         {
@@ -672,6 +679,7 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
             {
                 Reference->MenuPos=MI->Stream_Prepare(Stream_Menu);
                 MI->Fill(Stream_Menu, Reference->MenuPos, General_ID, ID_Base);
+                MI->Fill(Stream_Menu, Reference->StreamPos, "Source", Reference->Source);
             }
             Ztring List=Reference->MI->Get(StreamKind_Last, StreamPos_From, General_ID);
             Ztring List_String=Reference->MI->Get(StreamKind_Last, StreamPos_From, General_ID_String);
@@ -684,7 +692,7 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
             MI->Fill(Stream_Menu, Reference->MenuPos, Menu_List_String, List_String);
         }
     }
-    if ((!Config->File_ID_OnlyRoot_Get() || Reference->MI->Count_Get(Stream_Video)+Reference->MI->Count_Get(Stream_Audio)>1) && !MI->Retrieve(StreamKind_Last, StreamPos_To, General_ID).empty())
+    if (!Reference->IsMain && (ContainerHasNoId || !Config->File_ID_OnlyRoot_Get() || Reference->MI->Count_Get(Stream_Video)+Reference->MI->Count_Get(Stream_Audio)>1) && !MI->Retrieve(StreamKind_Last, StreamPos_To, General_ID).empty())
     {
         if (!ID.empty())
             ID+=__T('-');
@@ -707,30 +715,111 @@ void File__ReferenceFilesHelper::ParseReference_Finalize_PerStream ()
             MenuID_String=ID_Base;
         }
     }
-    MI->Fill(StreamKind_Last, StreamPos_To, General_ID, ID, true);
-    MI->Fill(StreamKind_Last, StreamPos_To, General_ID_String, ID_String, true);
-    MI->Fill(StreamKind_Last, StreamPos_To, "MenuID", MenuID, true);
-    MI->Fill(StreamKind_Last, StreamPos_To, "MenuID/String", MenuID_String, true);
-    if (MI->Retrieve(StreamKind_Last, StreamPos_To, "Source").empty())
-        MI->Fill(StreamKind_Last, StreamPos_To, "Source", Reference->Source);
-    for (std::map<string, Ztring>::iterator Info=Reference->Infos.begin(); Info!=Reference->Infos.end(); Info++)
+    if (!Reference->IsMain)
+    {
+        MI->Fill(StreamKind_Last, StreamPos_To, General_ID, ID, true);
+        MI->Fill(StreamKind_Last, StreamPos_To, General_ID_String, ID_String, true);
+        MI->Fill(StreamKind_Last, StreamPos_To, "MenuID", MenuID, true);
+        MI->Fill(StreamKind_Last, StreamPos_To, "MenuID/String", MenuID_String, true);
+        if (MI->Retrieve(StreamKind_Last, StreamPos_To, "Source").empty())
+            MI->Fill(StreamKind_Last, StreamPos_To, "Source", Reference->Source);
+    }
+    for (std::map<string, Ztring>::iterator Info=Reference->Infos.begin(); Info!=Reference->Infos.end(); ++Info)
         MI->Fill(StreamKind_Last, StreamPos_To, Info->first.c_str(), Info->second);
 
     //Others
-    if (Reference->MI->Info && MI->Retrieve(StreamKind_Last, StreamPos_To, Reference->MI->Info->Fill_Parameter(StreamKind_Last, Generic_Format))!=Reference->MI->Info->Get(Stream_General, 0, General_Format))
+    if (!HasMainFile && Reference->MI->Info && MI->Retrieve(StreamKind_Last, StreamPos_To, Reference->MI->Info->Fill_Parameter(StreamKind_Last, Generic_Format))!=Reference->MI->Info->Get(Stream_General, 0, General_Format))
     {
         Ztring MuxingMode=MI->Retrieve(StreamKind_Last, StreamPos_To, "MuxingMode");
         if (!MuxingMode.empty())
             MuxingMode.insert(0, __T(" / "));
         MI->Fill(StreamKind_Last, StreamPos_To, "MuxingMode", Reference->MI->Info->Get(Stream_General, 0, General_Format)+MuxingMode, true);
     }
+
+    //Lists
+    #if MEDIAINFO_ADVANCED || MEDIAINFO_MD5
+        if (!Reference->List_Compute_Done && (Reference->MI->Count_Get(Stream_Menu)==0 || StreamKind_Last==Stream_Menu))
+        {
+            List_Compute();
+            Reference->List_Compute_Done=true;
+        }
+    #endif //MEDIAINFO_ADVANCED || MEDIAINFO_MD5
 }
 
+//---------------------------------------------------------------------------
+#if MEDIAINFO_ADVANCED || MEDIAINFO_MD5
+void File__ReferenceFilesHelper::List_Compute()
+{
+    stream_t StreamKind=References.size()>1?StreamKind_Last:Stream_General;
+    size_t   StreamPos=References.size()>1?StreamPos_To:0;
+
+    stream_t StreamKind_Target=Reference->MenuPos==(size_t)-1?StreamKind:Stream_Menu;
+    size_t   StreamPos_Target=Reference->MenuPos==(size_t)-1?StreamPos:Reference->MenuPos;
+
+    //MD5
+    #if MEDIAINFO_MD5
+        if (!HasMainFile && Config->File_Md5_Get())
+        {
+            if (!Reference->MI->Get(Stream_General, 0, __T("MD5_Generated")).empty())
+            {
+                if (Reference->MI->Config.File_Names.size()==1)
+                {
+                    MI->Fill(StreamKind_Target, StreamPos_Target, "Source_MD5_Generated", Reference->MI->Get(Stream_General, 0, __T("MD5_Generated")));
+                    (*MI->Stream_More)[StreamKind_Target][StreamPos_Target](Ztring().From_Local("Source_MD5_Generated"), Info_Options)=__T("N NT");
+                }
+                MI->Fill(StreamKind_Target, StreamPos_Target, "Source_List_MD5_Generated", Reference->MI->Get(Stream_General, 0, __T("MD5_Generated")));
+                (*MI->Stream_More)[StreamKind_Target][StreamPos_Target](Ztring().From_Local("Source_List_MD5_Generated"), Info_Options)=__T("N NT");
+            }
+            if (!Reference->MI->Get(Stream_General, 0, __T("Source_List_MD5_Generated")).empty())
+            {
+                MI->Fill(StreamKind_Target, StreamPos_Target, "Source_List_MD5_Generated", Reference->MI->Get(Stream_General, 0, __T("Source_List_MD5_Generated")));
+                (*MI->Stream_More)[StreamKind_Target][StreamPos_Target](Ztring().From_Local("Source_List_MD5_Generated"), Info_Options)=__T("N NT");
+            }
+            else if (!Reference->MI->Get(StreamKind, StreamPos, __T("Source_List_MD5_Generated")).empty())
+            {
+                MI->Fill(StreamKind_Target, StreamPos_Target, "Source_List_MD5_Generated", Reference->MI->Get(StreamKind, StreamPos, __T("Source_List_MD5_Generated")));
+                (*MI->Stream_More)[StreamKind_Target][StreamPos_Target](Ztring().From_Local("Source_List_MD5_Generated"), Info_Options)=__T("N NT");
+            }
+        }
+    #endif //MEDIAINFO_MD5
+
+    //Source_List
+    #if MEDIAINFO_ADVANCED
+        if (!HasMainFile && Config->File_Source_List_Get())
+        {
+            Ztring SourcePath=FileName::Path_Get(MI->Retrieve(Stream_General, 0, General_CompleteName));
+            size_t SourcePath_Size=SourcePath.size()+1; //Path size + path separator size
+            for (size_t Pos=0; Pos<Reference->FileNames.size(); Pos++)
+            {
+                Ztring Temp=Reference->FileNames[Pos];
+                if (!Config->File_IsReferenced_Get())
+                    Temp.erase(0, SourcePath_Size);
+                MI->Fill(StreamKind_Target, StreamPos_Target, "Source_List", Temp);
+            }
+            if (!Reference->MI->Get(Stream_General, 0, __T("Source_List")).empty())
+            {
+                ZtringList List;
+                List.Separator_Set(0, __T(" / "));
+                List.Write(Reference->MI->Get(Stream_General, 0, __T("Source_List")));
+                for (size_t Pos=0; Pos<List.size(); Pos++)
+                {
+                    Ztring Temp=List[Pos];
+                    if (!Config->File_IsReferenced_Get())
+                        Temp.erase(0, SourcePath_Size);
+                    MI->Fill(StreamKind_Target, StreamPos_Target, "Source_List", Temp);
+                }
+            }
+            (*MI->Stream_More)[StreamKind_Target][StreamPos_Target](Ztring().From_Local("Source_List"), Info_Options)=__T("N NT");
+        }
+    #endif //MEDIAINFO_ADVANCED
+}
+#endif //defined(MEDIAINFO_ADVANCED) || defined(MEDIAINFO_MD5)
+
 //---------------------------------------------------------------------------
 void File__ReferenceFilesHelper::Read_Buffer_Unsynched()
 {
     MI->Open_Buffer_Unsynch();
-    for (references::iterator Reference=References.begin(); Reference!=References.end(); Reference++)
+    for (references::iterator Reference=References.begin(); Reference!=References.end(); ++Reference)
         if (Reference->MI)
             Reference->MI->Open_Buffer_Unsynch();
 
@@ -747,7 +836,7 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
     switch (Method)
     {
         case 0  :
-                    #if MEDIAINFO_DEMUX
+                    #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                         {
                         if (Value)
                         {
@@ -823,10 +912,11 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                         Open_Buffer_Unsynch();
                         return HasProblem?(size_t)-1:1; //Not supported value if there is a problem (TODO: better info)
                         }
-                    #else //MEDIAINFO_DEMUX
+                    #else //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                         return (size_t)-1; //Not supported
-                    #endif //MEDIAINFO_DEMUX
+                    #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
         case 1  :
+                    #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                     {
                         //Time percentage
                         int64u Duration=MI->Get(Stream_General, 0, General_Duration).To_int64u();
@@ -867,8 +957,11 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                         Open_Buffer_Unsynch();
                         return HasProblem?2:1; //Invalid value if there is a problem (TODO: better info)
                     }
+                    #else //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
+                        return (size_t)-1; //Not supported
+                    #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
         case 2  :   //Timestamp
-                    #if MEDIAINFO_DEMUX
+                    #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                     {
                         CountOfReferencesToParse=References.size();
                         Ztring Time; Time.Duration_From_Milliseconds(Value/1000000);
@@ -892,11 +985,11 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                         Open_Buffer_Unsynch();
                         return 1;
                     }
-                    #else //MEDIAINFO_DEMUX
+                    #else //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                         return (size_t)-1; //Not supported
-                    #endif //MEDIAINFO_DEMUX
+                    #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
         case 3  :   //FrameNumber
-                    #if MEDIAINFO_DEMUX
+                    #if MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                         CountOfReferencesToParse=References.size();
                         for (Reference=References.begin(); Reference!=References.end(); Reference++)
                         {
@@ -917,9 +1010,9 @@ size_t File__ReferenceFilesHelper::Read_Buffer_Seek (size_t Method, int64u Value
                         Reference=References.begin();
                         Open_Buffer_Unsynch();
                         return 1;
-                    #else //MEDIAINFO_DEMUX
+                    #else //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
                         return (size_t)-1; //Not supported
-                    #endif //MEDIAINFO_DEMUX
+                    #endif //MEDIAINFO_DEMUX && MEDIAINFO_NEXTPACKET
          default :   return 0;
     }
 }
@@ -934,7 +1027,7 @@ size_t File__ReferenceFilesHelper::Stream_Prepare (stream_t StreamKind, size_t S
 {
     size_t StreamPos_Last=MI->Stream_Prepare(StreamKind, StreamPos);
 
-    for (references::iterator ReferencePos=References.begin(); ReferencePos!=References.end(); ReferencePos++)
+    for (references::iterator ReferencePos=References.begin(); ReferencePos!=References.end(); ++ReferencePos)
         if (ReferencePos->StreamKind==StreamKind && ReferencePos->StreamPos>=StreamPos_Last)
             if (ReferencePos->StreamPos!=(size_t)-1)
                 ReferencePos->StreamPos++;
@@ -950,18 +1043,43 @@ void File__ReferenceFilesHelper::FileSize_Compute ()
 
     MI->Config->File_Size=MI->File_Size;
 
-    for (references::iterator Reference=References.begin(); Reference!=References.end(); Reference++)
+    for (references::iterator Reference=References.begin(); Reference!=References.end(); ++Reference)
     {
         if (Reference->FileSize!=(int64u)-1)
             MI->Config->File_Size+=Reference->FileSize;
         else if (Reference->MI && Reference->MI->Config.File_Size!=(int64u)-1)
             MI->Config->File_Size+=Reference->MI->Config.File_Size;
         else
-            for (size_t Pos=0; Pos<Reference->FileNames.size(); Pos++)
-                MI->Config->File_Size+=File::Size_Get(Reference->FileNames[Pos]);
+        {
+            #if MEDIAINFO_ADVANCED
+                if (!Config->File_IgnoreSequenceFileSize_Get())
+            #endif //MEDIAINFO_ADVANCED
+                    for (size_t Pos=0; Pos<Reference->FileNames.size(); Pos++)
+                        MI->Config->File_Size+=File::Size_Get(Reference->FileNames[Pos]);
+        }
     }
 }
 
+//---------------------------------------------------------------------------
+#if MEDIAINFO_EVENTS
+void File__ReferenceFilesHelper::SubFile_Start()
+{
+    if (Reference->StreamID!=StreamID_Previous)
+    {
+        Ztring FileName_Absolute, FileName_Relative;
+        if (Reference->MI && Reference->MI->Config.File_Names_Pos && Reference->MI->Config.File_Names_Pos<Reference->MI->Config.File_Names.size())
+            FileName_Absolute=Reference->MI->Config.File_Names[Reference->MI->Config.File_Names_Pos-1];
+        else if (!Reference->FileNames.empty())
+            FileName_Absolute=Reference->FileNames[0];
+        else
+            FileName_Absolute=Reference->Source.c_str();
+
+        Reference->MI->Config.Event_SubFile_Start(FileName_Absolute);
+        StreamID_Previous=Reference->StreamID;
+    }
+}
+#endif //MEDIAINFO_EVENTS
+
 } //NameSpace
 
 #endif //MEDIAINFO_REFERENCES_YES
