@@ -1,21 +1,8 @@
-// File__Tags - Info for all kind of framed tags tagged files
-// Copyright (C) 2005-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
 
 //---------------------------------------------------------------------------
 // Pre-compilation
@@ -69,7 +56,6 @@ File__Tags_Helper::File__Tags_Helper()
 
     //Temp
     Parser=NULL;
-    Parser_Streams_Fill=NULL;
     Id3v1_Offset=(int64u)-1;
     Lyrics3_Offset=(int64u)-1;
     Lyrics3v2_Offset=(int64u)-1;
@@ -87,7 +73,8 @@ File__Tags_Helper::File__Tags_Helper()
 File__Tags_Helper::~File__Tags_Helper()
 {
     delete Parser; //Parser=NULL;
-    delete Parser_Streams_Fill; //Parser_Streams_Fill=NULL;
+    for (size_t Pos=0; Pos<Parser_Streams_Fill.size(); Pos++)
+        delete Parser_Streams_Fill[Pos]; //Parser_Streams_Fill[Pos]=NULL;
 }
 
 //***************************************************************************
@@ -97,13 +84,23 @@ File__Tags_Helper::~File__Tags_Helper()
 //---------------------------------------------------------------------------
 void File__Tags_Helper::Streams_Fill()
 {
-    if (Parser_Streams_Fill && Parser_Streams_Fill->Status[File__Analyze::IsAccepted])
+    for (size_t Pos=0; Pos<Parser_Streams_Fill.size(); Pos++)
     {
-        Parser_Streams_Fill->Read_Buffer_Finalize();
-        Base->Merge(*Parser_Streams_Fill, Stream_General, 0, 0, false);
-        Base->Merge(*Parser_Streams_Fill, Stream_Audio  , 0, 0, false);
+        if (Parser_Streams_Fill[Pos] && Parser_Streams_Fill[Pos]->Status[File__Analyze::IsAccepted])
+        {
+            #ifndef MEDIAINFO_ID3V2_YES
+                const bool Priority=false;
+            #else
+                bool Priority=Parser_Streams_Fill_Priority[Pos];
+            #endif
+
+            Parser_Streams_Fill[Pos]->Read_Buffer_Finalize();
+            Base->Merge(*(Parser_Streams_Fill[Pos]), Stream_General, 0, 0, Priority);
+            Base->Merge(*(Parser_Streams_Fill[Pos]), Stream_Audio  , 0, 0, Priority);
+        }
+        delete Parser_Streams_Fill[Pos]; //Parser_Streams_Fill[Pos]=NULL;
     }
-    delete Parser_Streams_Fill; Parser_Streams_Fill=NULL;
+    Parser_Streams_Fill.clear();
 }
 
 //---------------------------------------------------------------------------
@@ -152,103 +149,144 @@ bool File__Tags_Helper::Synchronize(bool &Tag_Found, size_t Synchro_Offset)
         return false;
     }
 
-    //ID
-    if (Base->Buffer_Offset+Synchro_Offset+3>Base->Buffer_Size)
-        return false;
-    switch (Base->Buffer[Base->Buffer_Offset+Synchro_Offset])
+    if (!Synchro_Offset)
     {
-        case 0x49 : //"ID3"
-                    switch (CC3(Base->Buffer+Base->Buffer_Offset+Synchro_Offset))
-                    {
-                        case 0x494433 : //"ID3"
-                                        if (Synchro_Offset)
-                                        {
-                                            Tag_Found=true; //This is an ID3 tag after a complete chunk, waiting for the chunk to be parsed
-                                            return true;
-                                        }
-                                        if (!Synched_Test()) //Handling begin/intermediate Id3v2
-                                            return false;
-                                        return Synchronize(Tag_Found, Synchro_Offset);
-                        default       : if (Base->File_Offset+Base->Buffer_Offset==ApeTag_Offset)
-                                        {
-                                            Tag_Found=true;
-                                            return true;
-                                        };
-                    }
-                    break;
-        case 0x54 : //"TAG"
-        case 0x4C : //"LYR"
-        case 0x41 : //"APE"
-                    switch (CC3(Base->Buffer+Base->Buffer_Offset+Synchro_Offset))
-                    {
-                        case 0x544147 : //"TAG"
-                        case 0x4C5952 : //"LYR"
-                        case 0x415045 : //"APE"
-                                        if (TagSizeIsFinal && Base->File_Offset+Base->Buffer_Offset==Base->File_Size-File_EndTagSize)
-                                        {
-                                            Tag_Found=true;
-                                            return Synched_Test();
-                                        }
-                                        else if (Base->File_Offset+Base->Buffer_Size==Base->File_Size)
-                                        {
-                                             while (!TagSizeIsFinal && DetectBeginOfEndTags_Test());
-                                             Tag_Found=Base->File_Offset+Base->Buffer_Offset==Base->File_Size-File_EndTagSize;
-                                             return true;
-                                        }
-                                        else
-                                            return false; //Need more data
-                        default       : if (Base->File_Offset+Base->Buffer_Offset==ApeTag_Offset)
-                                        {
-                                            Tag_Found=true;
-                                            return true;
-                                        };
-                    }
-                    break;
-        default   : if (Base->File_Offset+Base->Buffer_Offset==ApeTag_Offset)
-                    {
-                        Tag_Found=true;
-                        return true;
-                    };
+        if (!Synched_Test()) //Handling begin/intermediate Id3v2
+            return false;
     }
 
-    Tag_Found=false;
-    return Base->File_GoTo==(int64u)-1;
+    //ID
+    if (Base->Buffer_Offset+Synchro_Offset+8>Base->Buffer_Size)
+        return false;
+    int32u ID3=CC3(Base->Buffer+Base->Buffer_Offset+Synchro_Offset);
+    int64u ID8=CC8(Base->Buffer+Base->Buffer_Offset+Synchro_Offset);
+    if (ID3==0x494433 //"ID3"
+     || ID8==0x4150455441474558LL //"APETAGEX"
+     || ID8==0x4C59524943534245LL //"LYRICSBE"
+     || ID3==0x544147) //"TAG" / "TAG+"
+        Tag_Found=true;
+    else
+        Tag_Found=false;
+
+    return true;
 }
 
 //---------------------------------------------------------------------------
 bool File__Tags_Helper::Synched_Test()
 {
+    if (SearchingForEndTags)
+        return true;
+
     for (;;)
     {
+        #ifdef MEDIAINFO_ID3V2_YES
+            bool Priority=false;
+        #else
+            const bool Priority=false;
+        #endif
+
         if (!Parser)
         {
             //Must have enough buffer for having header
-            if (Base->Buffer_Offset+4>Base->Buffer_Size)
+            if (Base->Buffer_Offset+8>Base->Buffer_Size)
                 return Base->IsSub; //If IsSub, we consider this is a complete block
 
             //Quick test of synchro
             int32u ID=CC3(Base->Buffer+Base->Buffer_Offset);
             int32u ID4=CC4(Base->Buffer+Base->Buffer_Offset);
+            int64u ID8=CC8(Base->Buffer+Base->Buffer_Offset);
                  if (ID==0x494433) //"ID3"
             {
                 if (Base->Buffer_Offset+10>Base->Buffer_Size)
                     return false;
-                #ifdef MEDIAINFO_ID3V2_YES
-                    Parser=new File_Id3v2;
-                #else
-                    Parser=new File_Unknown;
-                #endif
                 int32u Size=BigEndian2int32u(Base->Buffer+Base->Buffer_Offset+6);
                 Parser_Buffer_Size=(((Size>>0)&0x7F)
                                   | ((Size>>1)&0x3F80)
                                   | ((Size>>2)&0x1FC000)
                                   | ((Size>>3)&0x0FE00000))
                                   +10;
-                File_BeginTagSize+=Parser_Buffer_Size;
+                if (Base->Buffer_Offset+Parser_Buffer_Size>Base->Buffer_Size)
+                    return false;
+                if (!TagSizeIsFinal)
+                    File_BeginTagSize+=Parser_Buffer_Size;
                 if (Base->File_Offset_FirstSynched==(int64u)-1)
                     Base->Buffer_TotalBytes_FirstSynched_Max+=Parser_Buffer_Size;
+                #ifdef MEDIAINFO_ID3V2_YES
+                    Parser=new File_Id3v2;
+                    Priority=true;
+                #else
+                    Parser=new File_Unknown;
+                #endif
                 Base->Element_Begin1("Id3v2");
             }
+            else if (ID8==0x4150455441474558LL) //"APETAGEX"
+            {
+                if (Base->Buffer_Offset+16>Base->Buffer_Size)
+                    return false;
+                Parser_Buffer_Size=LittleEndian2int32u(Base->Buffer+Base->Buffer_Offset+12);
+                if (LittleEndian2int32u(Base->Buffer+Base->Buffer_Offset+8))
+                    Parser_Buffer_Size+=32;
+                if (Base->Buffer_Offset+Parser_Buffer_Size>Base->Buffer_Size)
+                    return false;
+                if (!TagSizeIsFinal)
+                    File_BeginTagSize+=Parser_Buffer_Size;
+                if (Base->File_Offset_FirstSynched==(int64u)-1)
+                    Base->Buffer_TotalBytes_FirstSynched_Max+=Parser_Buffer_Size;
+                #ifdef MEDIAINFO_APETAG_YES
+                    Parser=new File_ApeTag;
+                #else
+                    Parser=new File_Unknown;
+                #endif
+                Base->Element_Begin1("ApeTag");
+            }
+            else if (ID8==0x4C59524943534245LL) //"LYRICSBE"
+            {
+                if (Base->Buffer_Offset+16>Base->Buffer_Size)
+                    return false;
+                //Searching for "LYRICS200"
+                std::string Buf((const char*)(Base->Buffer+Base->Buffer_Offset), Base->Buffer_Size-Base->Buffer_Offset);
+                size_t Pos2=Buf.find("LYRICS200");
+                size_t Pos1=std::string::npos;
+                if (Pos2==std::string::npos)
+                    Pos1=Buf.find("LYRICSEND");
+                if (Pos2!=std::string::npos)
+                    Parser_Buffer_Size=Pos2+9;
+                else if (Pos1!=std::string::npos)
+                    Parser_Buffer_Size=Pos1+9;
+                else
+                    Parser_Buffer_Size=(size_t)(Base->File_Size-(Base->File_Offset+Base->Buffer_Offset));
+                if (Base->Buffer_Offset+Parser_Buffer_Size>Base->Buffer_Size)
+                    return false;
+                if (!TagSizeIsFinal)
+                    File_BeginTagSize+=Parser_Buffer_Size;
+                if (Base->File_Offset_FirstSynched==(int64u)-1)
+                    Base->Buffer_TotalBytes_FirstSynched_Max+=Parser_Buffer_Size;
+                if (Pos2!=std::string::npos)
+                {
+                    #ifdef MEDIAINFO_LYRICS3V2_YES
+                        Parser=new File_Lyrics3v2;
+                        ((File_Lyrics3v2*)Parser)->TotalSize=Parser_Buffer_Size;
+                    #else
+                        Parser=new File_Unknown;
+                    #endif
+                    Base->Element_Begin1("Lyrics2");
+                }
+                else if (Pos1!=std::string::npos)
+                {
+                    #ifdef MEDIAINFO_LYRICS3_YES
+                        Parser=new File_Lyrics3;
+                        ((File_Lyrics3*)Parser)->TotalSize=Parser_Buffer_Size;
+                    #else
+                        Parser=new File_Unknown;
+                    #endif
+                    Base->Element_Begin1("Lyrics");
+                }
+                else
+                {
+                    Parser=new File_Unknown;
+                    Base->Element_Begin1("Problem");
+                }
+            }
             else if (ID4==0x5441472B) //"TAG+"
             {
                 #ifdef MEDIAINFO_ID3_YES
@@ -267,6 +305,8 @@ bool File__Tags_Helper::Synched_Test()
                     Parser=new File_Unknown;
                 #endif
                 Parser_Buffer_Size=128;
+                if (!TagSizeIsFinal)
+                    File_BeginTagSize+=Parser_Buffer_Size;
                 Base->Element_Begin1("Id3");
             }
             else if (Base->File_Offset+Base->Buffer_Offset==Lyrics3_Offset)
@@ -278,6 +318,8 @@ bool File__Tags_Helper::Synched_Test()
                     Parser=new File__Analyze;
                 #endif
                 Parser_Buffer_Size=(size_t)Lyrics3_Size;
+                if (!TagSizeIsFinal)
+                    File_BeginTagSize+=Parser_Buffer_Size;
                 Base->Element_Begin1("Lyrics3");
             }
             else if (Base->File_Offset+Base->Buffer_Offset==Lyrics3v2_Offset)
@@ -289,6 +331,8 @@ bool File__Tags_Helper::Synched_Test()
                     Parser=new File_Unknown;
                 #endif
                 Parser_Buffer_Size=(size_t)Lyrics3v2_Size;
+                if (!TagSizeIsFinal)
+                    File_BeginTagSize+=Parser_Buffer_Size;
                 Base->Element_Begin1("Lyrics3v2");
             }
             else if (Base->File_Offset+Base->Buffer_Offset==ApeTag_Offset)
@@ -298,6 +342,8 @@ bool File__Tags_Helper::Synched_Test()
                 #else
                     Parser=new File_Unknown;
                 #endif
+                if (!TagSizeIsFinal)
+                    File_BeginTagSize+=Parser_Buffer_Size;
                 Parser_Buffer_Size=(size_t)ApeTag_Size;
                 Base->Element_Begin1("ApeTag");
             }
@@ -321,17 +367,17 @@ bool File__Tags_Helper::Synched_Test()
                     if (!Base->Status[File__Analyze::IsFilled])
                         Base->Fill();
                     Parser->Read_Buffer_Finalize();
-                    Base->Merge(*Parser, Stream_General, 0, 0, false);
-                    Base->Merge(*Parser, Stream_Audio  , 0, 0, false);
+                    Base->Merge(*Parser, Stream_General, 0, 0, Priority);
+                    Base->Merge(*Parser, Stream_Audio  , 0, 0, Priority);
                     delete Parser; Parser=NULL;
                 }
-                else if (Parser_Streams_Fill==NULL) //Currently using only the first detected tag
-                {
-                    Parser_Streams_Fill=Parser; Parser=NULL;
-                }
                 else
                 {
-                    delete Parser; Parser=NULL;
+                    Parser_Streams_Fill.push_back(Parser);
+                    #ifdef MEDIAINFO_ID3V2_YES
+                        Parser_Streams_Fill_Priority.push_back(Priority);
+                    #endif
+                    Parser=NULL;
                 }
                 if (Parser_Buffer_Size)
                     Base->Skip_XX(Parser_Buffer_Size,           "Data continued");
