@@ -1,20 +1,9 @@
-// File_Mpegv - Info for MPEG Video files
-// Copyright (C) 2004-2012 MediaArea.net SARL, Info@MediaArea.net
-//
-// This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Library General Public License as published by
-// the Free Software Foundation, either version 2 of the License, or
-// any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public License
-// along with this library. If not, see <http://www.gnu.org/licenses/>.
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Information about MPEG Video files
@@ -51,6 +40,9 @@ public :
     #if defined(MEDIAINFO_ANCILLARY_YES)
         File_Ancillary** Ancillary;
     #endif //defined(MEDIAINFO_ANCILLARY_YES)
+    #if MEDIAINFO_ADVANCED
+        bool    InitDataNotRepeated_Optional;
+    #endif // MEDIAINFO_ADVANCED
 
     //Constructor/Destructor
     File_Mpegv();
@@ -222,11 +214,11 @@ private :
         File__Analyze*              DTG1_Parser;
         File__Analyze*              GA94_06_Parser;
     #endif //defined(MEDIAINFO_AFDBARDATA_YES)
-    #if defined(MEDIAINFO_GXF_YES) && defined(MEDIAINFO_CDP_YES)
+    #if defined(MEDIAINFO_CDP_YES)
         File__Analyze*              Cdp_Parser;
         bool                        Cdp_IsPresent;
     #endif //defined(MEDIAINFO_GXF_YES) && defined(MEDIAINFO_CDP_YES)
-    #if defined(MEDIAINFO_GXF_YES) && defined(MEDIAINFO_AFDBARDATA_YES)
+    #if defined(MEDIAINFO_AFDBARDATA_YES)
         File__Analyze*              AfdBarData_Parser;
     #endif //defined(MEDIAINFO_GXF_YES) && defined(MEDIAINFO_AFDBARDATA_YES)
 
@@ -236,6 +228,7 @@ private :
     Ztring Library_Version;
     Ztring Matrix_intra;
     Ztring Matrix_nonintra;
+    string TimeCode_FirstFrame;
     size_t BVOP_Count;
     size_t progressive_frame_Count;
     size_t Interlaced_Top;
@@ -301,6 +294,9 @@ private :
     int64u PTS_LastIFrame;
     int64u tc;
     bool    IFrame_IsParsed;
+    size_t  IFrame_Count;
+    std::map<std::string, int64u>   picture_coding_types; //per picture_coding_type value ("IPBB..."), updated at each I-frame
+    std::string                     picture_coding_types_Current; //Current picture_coding_type value ("IPBB..."), updated at each frame
 
     #if MEDIAINFO_MACROBLOCKS
         int64u  macroblock_x;
@@ -335,6 +331,20 @@ private :
     #if MEDIAINFO_IBI
         bool    Ibi_SliceParsed;
     #endif //MEDIAINFO_IBI
+
+    #if MEDIAINFO_ADVANCED
+        int64u  InitDataNotRepeated;
+        int64u  Config_InitDataNotRepeated_Occurences;
+        bool    Config_InitDataNotRepeated_GiveUp;
+        int64u  Config_VariableGopDetection_Occurences;
+        bool    Config_VariableGopDetection_GiveUp;
+    #endif // MEDIAINFO_ADVANCED
+
+    #if MEDIAINFO_ADVANCED || MEDIAINFO_EVENTS
+        size_t  Slices_Count;
+        bool    Has_sequence_header;
+        bool    Has_sequence_extension;
+    #endif // MEDIAINFO_ADVANCED || MEDIAINFO_EVENTS
 };
 
 } //NameSpace
