@@ -1,34 +1,9 @@
-// MediaInfoDLL - All info about media files, for DLL
-// Copyright (C) 2002-2009 Jerome Martinez, Zen@MediaArea.net
-//
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation; either
-// version 2.1 of the License, or (at your option) any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Lesser General Public License for more details.
-//
-// MediaInfoDLL - All info about media files, for DLL
-// Copyright (C) 2002-2009 Jerome Martinez, Zen@MediaArea.net
-//
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Lesser General Public
-// License as published by the Free Software Foundation; either
-// version 2.1 of the License, or (at your option) any later version.
-//
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Lesser General Public License for more details.
-//
-// You should have received a copy of the GNU Lesser General Public
-// License along with this library; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-//+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+/*  Copyright (c) MediaArea.net SARL. All Rights Reserved.
+ *
+ *  Use of this source code is governed by a BSD-style license that can
+ *  be found in the License.html file in the root of the source tree.
+ */
+
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 //
 // Microsoft Visual C# wrapper for MediaInfo Library
@@ -52,7 +27,7 @@ namespace MediaInfoLib
         Video,
         Audio,
         Text,
-        Chapters,
+        Other,
         Image,
         Menu,
     }
@@ -228,22 +203,6 @@ namespace MediaInfoLib
         public int Count_Get(StreamKind StreamKind) { return Count_Get(StreamKind, -1); }
     }
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
     public class MediaInfoList
     {
         //Import of DLL functions. DO NOT USE until you know what you do (MediaInfo DLL do NOT use CoTaskMemAlloc to allocate memory)
